<?php
require get_template_directory() . '/inc/helpers.php';
require get_template_directory() . '/inc/sanitization.php';
require get_template_directory() . '/inc/functions.php';
require get_template_directory() . '/inc/helpers-post-meta.php';
require get_template_directory() . '/inc/custom-fields-product.php';
require get_template_directory() . '/inc/customizer.php';
require get_template_directory() . '/inc/customizer-styles.php';
require get_template_directory() . '/inc/term-meta.php';
require get_template_directory() . '/inc/woocommerce.php';
require get_template_directory() . '/inc/visual-composer.php';
require get_template_directory() . '/inc/class-wc-shortcodes.php';
if ( defined( 'ELEMENTOR_VERSION' ) && version_compare( PHP_VERSION, '5.4', '>=' ) ) {
	require_once get_theme_file_path( '/inc/elementor.php' );
}

add_action( 'after_setup_theme', 'neto_content_width', 0 );
function neto_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'neto_content_width', 750 );
}

add_action( 'after_setup_theme', 'neto_setup' );
if ( ! function_exists( 'neto_setup' ) ) :
	function neto_setup() {

		if ( ! defined( 'NETO_NAME' ) ) {
			define( 'NETO_NAME', 'neto' );
		}
		if ( ! defined( 'NETO_WHITELABEL' ) ) {
			// Set the following to true, if you want to remove any user-facing CSSIgniter traces.
			define( 'NETO_WHITELABEL', false );
		}

		load_theme_textdomain( 'neto', get_template_directory() . '/languages' );

		/*
		 * Theme supports.
		 */
		add_theme_support( 'automatic-feed-links' );
		add_theme_support( 'title-tag' );
		add_theme_support( 'post-thumbnails' );
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		add_theme_support( 'custom-logo', array(
			'height'      => 45,
			'width'       => 165,
			'flex-height' => true,
			'flex-width'  => true,
		) );

		add_theme_support( 'custom-background', array(
			'default-repeat'     => 'no-repeat',
			'default-position-x' => 'center',
			'wp-head-callback'   => 'neto_custom_background_cb',
		) );


		/*
		 * Image sizes.
		 */
		set_post_thumbnail_size( 750, 500, true );
		add_image_size( 'neto_item', 540, 730, true );
		add_image_size( 'neto_fullwidth', 1140, 500, true );
		add_image_size( 'neto_hero', 1920, 300, true );
		add_image_size( 'neto_about', 360, 220, true );

		/*
		 * Navigation menus.
		 */
		register_nav_menus( array(
			'main_menu'      => esc_html__( 'Main Menu', 'neto' ),
			'secondary_menu' => esc_html__( 'Secondary Menu', 'neto' ),
			'footer_menu'    => esc_html__( 'Footer Menu', 'neto' ),
		) );


		/*
		 * Default hooks
		 */
		// Prints the inline JS scripts that are registered for printing, and removes them from the queue.
		add_action( 'admin_footer', 'neto_print_inline_js' );
		add_action( 'wp_footer', 'neto_print_inline_js' );

		// Handle the dismissible sample content notice.
		add_action( 'admin_notices', 'neto_admin_notice_sample_content' );
		add_action( 'wp_ajax_neto_dismiss_sample_content', 'neto_ajax_dismiss_sample_content' );

		// Wraps post counts in span.ci-count
		// Needed for the default widgets, however more appropriate filters don't exist.
		add_filter( 'get_archives_link', 'neto_wrap_archive_widget_post_counts_in_span', 10, 2 );
		add_filter( 'wp_list_categories', 'neto_wrap_category_widget_post_counts_in_span', 10, 2 );
	}
endif;



add_action( 'wp_enqueue_scripts', 'neto_enqueue_scripts' );
function neto_enqueue_scripts() {

	/*
	 * Styles
	 */
	$theme = wp_get_theme();

	$font_url = '';
	/* translators: If there are characters in your language that are not supported by Lato or Roboto Slab, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Lato and Montserrat fonts: on or off', 'neto' ) ) {
		$font_url = add_query_arg( 'family', 'Lato:400,400i,700%7CMontserrat:400,700', '//fonts.googleapis.com/css' );
	}
	wp_register_style( 'neto-google-font', esc_url( $font_url ) );

	wp_register_style( 'neto-base', get_template_directory_uri() . '/css/base.css', array(), $theme->get( 'Version' ) );
	wp_register_style( 'mmenu', get_template_directory_uri() . '/css/mmenu.css', array(), '5.5.3' );
	wp_register_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css', array(), '4.7.0' );
	wp_register_style( 'magnific-popup', get_template_directory_uri() . '/css/magnific.css', array(), '1.0.0' );
	wp_register_style( 'slick', get_template_directory_uri() . '/css/slick.css', array(), '1.5.7' );
	wp_register_style( 'm-custom-scrollbar', get_template_directory_uri() . '/css/jquery.mCustomScrollbar.min.css', array(), '3.1.13' );

	wp_register_style( 'neto-dependencies', false, array(
		'neto-google-font',
		'neto-base',
		'neto-common',
		'mmenu',
		'font-awesome',
		'magnific-popup',
		'slick',
		'm-custom-scrollbar',
	), $theme->get( 'Version' ) );

	if ( is_child_theme() ) {
		wp_enqueue_style( 'neto-style-parent', get_template_directory_uri() . '/style.css', array(
			'neto-dependencies',
		), $theme->get( 'Version' ) );
	}

	wp_enqueue_style( 'neto-style', get_stylesheet_uri(), array(
		'neto-dependencies',
	), $theme->get( 'Version' ) );

	wp_add_inline_style( 'neto-style', neto_get_customizer_css() );

	$hero_style = neto_get_section_styles();
	if ( ! empty( $hero_style ) ) {
		$hero_style = sprintf( '.page-hero { %s }', $hero_style );
		wp_add_inline_style( 'neto-style', $hero_style );
	}


	/*
	 * Scripts
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	wp_register_script( 'superfish', get_template_directory_uri() . '/js/superfish.js', array( 'jquery' ), '1.7.5', true );
	wp_register_script( 'mmenu', get_template_directory_uri() . '/js/jquery.mmenu.min.all.js', array( 'jquery' ), '5.5.3', true );
	wp_register_script( 'fitVids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '1.1', true );
	wp_register_script( 'magnific-popup', get_template_directory_uri() . '/js/jquery.magnific-popup.js', array( 'jquery' ), '1.0.0', true );
	wp_register_script( 'match-height', get_template_directory_uri() . '/js/jquery.matchHeight.js', array( 'jquery' ), '1.0.0', true );
	wp_register_script( 'slick', get_template_directory_uri() . '/js/slick.min.js', array( 'jquery' ), '1.5.7', true );
	wp_register_script( 'sticky-kit', get_template_directory_uri() . '/js/jquery.sticky-kit.min.js', array( 'jquery' ), '1.1.4' );
	wp_register_script( 'm-custom-scrollbar', get_template_directory_uri() . '/js/jquery.mCustomScrollbar.concat.min.js', array( 'jquery' ), '3.1.13' );

	/*
	 * Enqueue
	 */
	wp_enqueue_script( 'neto-front-scripts', get_template_directory_uri() . '/js/scripts.js', array(
		'jquery',
		'superfish',
		'mmenu',
		'fitVids',
		'magnific-popup',
		'match-height',
		'slick',
		'sticky-kit',
		'm-custom-scrollbar',
	), $theme->get( 'Version' ), true );

}

add_action( 'admin_enqueue_scripts', 'neto_admin_enqueue_scripts' );
function neto_admin_enqueue_scripts( $hook ) {
	$theme = wp_get_theme();

	/*
	 * Styles
	 */
	wp_register_style( 'neto-widgets', get_template_directory_uri() . '/css/admin/widgets.css', array(), $theme->get( 'Version' ) );


	/*
	 * Scripts
	 */
	wp_register_script( 'neto-widgets', get_template_directory_uri() . '/js/admin/widgets.js', array( 'jquery' ), $theme->get( 'Version' ), true );
	$params = array(
		'ajaxurl' => admin_url( 'admin-ajax.php' ),
	);
	wp_localize_script( 'neto-widgets', 'ThemeWidget', $params );

	wp_register_script( 'neto-term-edit', get_template_directory_uri() . '/js/admin/term-edit.js', array(
		'jquery',
		'wp-color-picker',
	), $theme->get( 'Version' ), true );


	/*
	 * Enqueue
	 */
	if ( in_array( $hook, array( 'edit-tags.php', 'term.php' ), true ) ) {
		wp_enqueue_media();
		wp_enqueue_style( 'neto-post-meta' );
		wp_enqueue_script( 'neto-post-meta' );

		wp_enqueue_script( 'neto-term-edit' );
		wp_enqueue_style( 'wp-color-picker' );
	}

	if ( in_array( $hook, array( 'post.php', 'post-new.php' ), true ) ) {
		wp_enqueue_media();
		wp_enqueue_style( 'neto-post-meta' );
		wp_enqueue_script( 'neto-post-meta' );
	}

	if ( in_array( $hook, array( 'widgets.php', 'customize.php' ), true ) ) {
		wp_enqueue_media();
		wp_enqueue_style( 'neto-widgets' );
		wp_enqueue_script( 'neto-widgets' );
		wp_enqueue_style( 'neto-post-meta' );
		wp_enqueue_script( 'neto-post-meta' );
	}

}


add_action( 'widgets_init', 'neto_widgets_init' );
function neto_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html_x( 'Blog', 'widget area', 'neto' ),
		'id'            => 'blog',
		'description'   => esc_html__( 'This sidebar appears on your blog section and posts.', 'neto' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Pages', 'widget area', 'neto' ),
		'id'            => 'page',
		'description'   => esc_html__( "This sidebar appears on the rest of your site's pages.", 'neto' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Home page', 'widget area', 'neto' ),
		'id'            => 'frontpage',
		'description'   => esc_html__( 'This sidebar appears on pages that have the "Home page" template assigned.', 'neto' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer - Column 1', 'widget area', 'neto' ),
		'id'            => 'footer-1',
		'description'   => esc_html__( 'First column on footer.', 'neto' ),
		'before_widget' => '<section id="%1$s" class="widget  %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer - Column 2', 'widget area', 'neto' ),
		'id'            => 'footer-2',
		'description'   => esc_html__( 'Second column on footer.', 'neto' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer - Column 3', 'widget area', 'neto' ),
		'id'            => 'footer-3',
		'description'   => esc_html__( 'Third column on footer.', 'neto' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer - Column 4', 'widget area', 'neto' ),
		'id'            => 'footer-4',
		'description'   => esc_html__( 'Fourth column on footer.', 'neto' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html_x( 'Footer - Instagram', 'widget area', 'neto' ),
		'id'            => 'footer-instagram',
		'description'   => esc_html__( 'Special site-wide area for the WP Instagram Widget plugin.', 'neto' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );


	register_sidebar( array(
		'name'          => esc_html_x( 'Shop Widgets', 'widget area', 'neto' ),
		'id'            => 'eshop',
		'description'   => esc_html__( 'This widget area appears on your shop pages (requires WooCommerce).', 'neto' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}


add_action( 'widgets_init', 'neto_load_widgets' );
function neto_load_widgets() {
	require get_template_directory() . '/inc/widgets/about-me.php';
	require get_template_directory() . '/inc/widgets/latest-posts.php';
	require get_template_directory() . '/inc/widgets/socials.php';

	if ( class_exists( 'WooCommerce' ) ) {
		require get_template_directory() . '/inc/widgets/wc-product-category.php';
		require get_template_directory() . '/inc/widgets/wc-product-categories.php';
		require get_template_directory() . '/inc/widgets/wc-product.php';
		require get_template_directory() . '/inc/widgets/wc-products.php';
		require get_template_directory() . '/inc/widgets/wc-sale-products.php';
		require get_template_directory() . '/inc/widgets/wc-best-selling-products.php';
		require get_template_directory() . '/inc/widgets/wc-top-rated-products.php';
		require get_template_directory() . '/inc/widgets/wc-featured-products.php';
		require get_template_directory() . '/inc/widgets/wc-recent-products.php';
		require get_template_directory() . '/inc/widgets/wc-product-attribute.php';
	}
}

add_action( 'after_setup_theme', 'neto_load_woocommerce_shortcodes' );
function neto_load_woocommerce_shortcodes() {
	if ( class_exists( 'WooCommerce' ) ) {
		remove_action( 'init', array( 'WC_Shortcodes', 'init' ) );
		add_action( 'init', array( 'Neto_WC_Shortcodes', 'init' ) );
	}
}


add_filter( 'excerpt_length', 'neto_excerpt_length' );
function neto_excerpt_length( $length ) {
	return get_theme_mod( 'excerpt_length', 55 );
}


add_filter( 'the_content', 'neto_lightbox_rel', 12 );
add_filter( 'get_comment_text', 'neto_lightbox_rel' );
if ( ! function_exists( 'neto_lightbox_rel' ) ) :
	function neto_lightbox_rel( $content ) {
		global $post;
		$pattern     = "/<a(.*?)href=('|\")([^>]*).(bmp|gif|jpeg|jpg|png)('|\")(.*?)>(.*?)<\/a>/i";
		$replacement = '<a$1href=$2$3.$4$5 data-lightbox="gal[' . $post->ID . ']"$6>$7</a>';
		$content     = preg_replace( $pattern, $replacement, $content );

		return $content;
	}
endif;


if ( ! function_exists( 'neto_get_social_networks' ) ) :
	function neto_get_social_networks() {
		return apply_filters( 'neto_social_networks', array(
			array(
				'name'  => 'facebook',
				'label' => esc_html__( 'Facebook', 'neto' ),
				'icon'  => 'fa-facebook',
			),
			array(
				'name'  => 'twitter',
				'label' => esc_html__( 'Twitter', 'neto' ),
				'icon'  => 'fa-twitter',
			),
			array(
				'name'  => 'pinterest',
				'label' => esc_html__( 'Pinterest', 'neto' ),
				'icon'  => 'fa-pinterest',
			),
			array(
				'name'  => 'instagram',
				'label' => esc_html__( 'Instagram', 'neto' ),
				'icon'  => 'fa-instagram',
			),
			array(
				'name'  => 'gplus',
				'label' => esc_html__( 'Google Plus', 'neto' ),
				'icon'  => 'fa-google-plus',
			),
			array(
				'name'  => 'linkedin',
				'label' => esc_html__( 'LinkedIn', 'neto' ),
				'icon'  => 'fa-linkedin',
			),
			array(
				'name'  => 'tumblr',
				'label' => esc_html__( 'Tumblr', 'neto' ),
				'icon'  => 'fa-tumblr',
			),
			array(
				'name'  => 'flickr',
				'label' => esc_html__( 'Flickr', 'neto' ),
				'icon'  => 'fa-flickr',
			),
			array(
				'name'  => 'bloglovin',
				'label' => esc_html__( 'Bloglovin', 'neto' ),
				'icon'  => 'fa-heart',
			),
			array(
				'name'  => 'youtube',
				'label' => esc_html__( 'YouTube', 'neto' ),
				'icon'  => 'fa-youtube',
			),
			array(
				'name'  => 'vimeo',
				'label' => esc_html__( 'Vimeo', 'neto' ),
				'icon'  => 'fa-vimeo',
			),
			array(
				'name'  => 'dribbble',
				'label' => esc_html__( 'Dribbble', 'neto' ),
				'icon'  => 'fa-dribbble',
			),
			array(
				'name'  => 'wordpress',
				'label' => esc_html__( 'WordPress', 'neto' ),
				'icon'  => 'fa-wordpress',
			),
			array(
				'name'  => '500px',
				'label' => esc_html__( '500px', 'neto' ),
				'icon'  => 'fa-500px',
			),
			array(
				'name'  => 'soundcloud',
				'label' => esc_html__( 'Soundcloud', 'neto' ),
				'icon'  => 'fa-soundcloud',
			),
			array(
				'name'  => 'spotify',
				'label' => esc_html__( 'Spotify', 'neto' ),
				'icon'  => 'fa-spotify',
			),
			array(
				'name'  => 'vine',
				'label' => esc_html__( 'Vine', 'neto' ),
				'icon'  => 'fa-vine',
			),
		) );
	}
endif;

if ( ! function_exists( 'neto_get_columns_classes' ) ) :
	function neto_get_columns_classes( $columns ) {
		switch ( intval( $columns ) ) {
			case 1:
				$classes = 'col-xs-12';
				break;
			case 2:
				$classes = 'col-sm-6 col-xs-12';
				break;
			case 3:
				$classes = 'col-lg-4 col-sm-6 col-xs-12';
				break;
			case 4:
			default:
				$classes = 'col-lg-3 col-md-4 col-sm-6 col-xs-12';
				break;
		}

		return apply_filters( 'neto_get_columns_classes', $classes, $columns );
	}
endif;

if ( ! function_exists( 'neto_get_blog_columns_choices' ) ) :
	function neto_get_blog_columns_choices() {
		$min = apply_filters( 'neto_blog_columns_min', 3 );
		$max = apply_filters( 'neto_blog_columns_max', 4 );

		$options = array();
		for ( $i = $min; $i <= $max; $i ++ ) {
			$options[ $i ] = esc_html( sprintf( _n( '%s Column', '%s Columns', $i, 'neto' ), $i ) );
		}

		return apply_filters( 'neto_blog_columns_choices', $options, $min, $max );
	}
endif;

if ( ! function_exists( 'neto_sanitize_blog_columns' ) ) :
	function neto_sanitize_blog_columns( $value ) {
		$value   = intval( $value );
		$choices = neto_get_blog_columns_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_blog_columns_default', 3 );
	}
endif;

if ( ! function_exists( 'neto_get_section_styles' ) ) :
	function neto_get_section_styles() {
		$style      = '';
		$color      = '';
		$bg_color   = '';
		$image      = '';
		$repeat     = '';
		$position_x = '';
		$position_y = '';
		$attachment = '';
		$cover      = '';
		$context    = '';

		if ( function_exists( 'is_shop' ) && is_shop() ) {
			$color      = get_theme_mod( 'woocommerce_shop_header_color' );
			$bg_color   = get_theme_mod( 'woocommerce_shop_header_bg_color' );
			$image      = get_theme_mod( 'woocommerce_shop_header_image' );
			$repeat     = get_theme_mod( 'woocommerce_shop_header_image_repeat' );
			$position_x = get_theme_mod( 'woocommerce_shop_header_image_position_x', 'center' );
			$position_y = get_theme_mod( 'woocommerce_shop_header_image_position_y', 'center' );
			$attachment = get_theme_mod( 'woocommerce_shop_header_image_attachment' );
			$cover      = get_theme_mod( 'woocommerce_shop_header_image_cover' );
			$context    = 'shop';
		} elseif ( function_exists( 'is_product_category' ) && is_product_category() ) {
			$color      = get_term_meta( get_queried_object_id(), 'header_color', true );
			$bg_color   = get_term_meta( get_queried_object_id(), 'header_bg_color', true );
			$image_id   = get_term_meta( get_queried_object_id(), 'header_image_id', true );
			$image      = neto_get_image_src( $image_id, 'full' );
			$repeat     = get_term_meta( get_queried_object_id(), 'header_image_repeat', true );
			$position_x = neto_sanitize_image_position_x( get_term_meta( get_queried_object_id(), 'header_image_position_x', true ) );
			$position_y = neto_sanitize_image_position_y( get_term_meta( get_queried_object_id(), 'header_image_position_y', true ) );
			$attachment = get_term_meta( get_queried_object_id(), 'header_image_attachment', true );
			$cover      = get_term_meta( get_queried_object_id(), 'header_image_cover', true );
			$context    = 'product_category';
		} elseif ( is_category() || is_tag() ) {
			$color      = get_theme_mod( 'category_header_color' );
			$bg_color   = get_theme_mod( 'category_header_bg_color' );
			$image      = get_theme_mod( 'category_header_image' );
			$repeat     = get_theme_mod( 'category_header_image_repeat' );
			$position_x = get_theme_mod( 'category_header_image_position_x', 'center' );
			$position_y = get_theme_mod( 'category_header_image_position_y', 'center' );
			$attachment = get_theme_mod( 'category_header_image_attachment' );
			$cover      = get_theme_mod( 'category_header_image_cover' );
			$context    = 'category_tag';
		}

		// Apply global options if applicable
		$bg_color = ! empty( $bg_color ) ? $bg_color : get_theme_mod( 'global_header_bg_color' );
		$color    = ! empty( $color ) ? $color : get_theme_mod( 'global_header_color' );
		if ( empty( $image ) ) {
			$image      = get_theme_mod( 'global_header_image' );
			$repeat     = get_theme_mod( 'global_header_image_repeat' );
			$position_x = get_theme_mod( 'global_header_image_position_x', 'center' );
			$position_y = get_theme_mod( 'global_header_image_position_y', 'center' );
			$attachment = get_theme_mod( 'global_header_image_attachment' );
			$cover      = get_theme_mod( 'global_header_image_cover' );
		}


		// Handle output
		if ( ! empty( $bg_color ) ) {
			$style .= sprintf( 'background-color: %s; ', $bg_color );
		}

		if ( ! empty( $color ) ) {
			$style .= sprintf( 'color: %s; ', $color );
		}

		if ( ! empty( $image ) ) {
			$style .= sprintf( "background-image: url('%s'); ",
				esc_url_raw( $image )
			);

			if ( ! empty( $repeat ) ) {
				$style .= sprintf( 'background-repeat: %s; ',
					$repeat
				);
			}

			if ( ! empty( $position_x ) && ! empty( $position_y ) ) {
				$style .= sprintf( 'background-position: %s %s; ',
					$position_y,
					$position_x
				);
			}

			if ( ! empty( $attachment ) ) {
				$style .= sprintf( 'background-attachment: %s; ',
					$attachment
				);
			}

			if ( ! empty( $cover ) ) {
				$style .= 'background-size: cover; ';
			}
		}

		return apply_filters( 'neto_section_styles', $style, $context, array(
			'color'      => $color,
			'bg_color'   => $bg_color,
			'image'      => $image,
			'repeat'     => $repeat,
			'position_x' => $position_x,
			'position_y' => $position_y,
			'attachment' => $attachment,
			'cover'      => $cover,
		) );
	}
endif;

if ( ! function_exists( 'neto_get_section_align_class' ) ) :
	function neto_get_section_align_class() {
		$class   = '';
		$align   = '';
		$context = '';

		if ( function_exists( 'is_shop' ) && is_shop() ) {
			$align   = get_theme_mod( 'woocommerce_shop_header_align', 'left' );
			$context = 'shop';
		} elseif ( function_exists( 'is_product_category' ) && is_product_category() ) {
			$align   = get_term_meta( get_queried_object_id(), 'header_align', true );
			$align   = ! empty( $align ) ? $align : 'center';
			$context = 'product_category';
		} elseif ( is_category() || is_tag() ) {
			$align   = get_theme_mod( 'category_header_align', 'center' );
			$context = 'category_tag';
		} else {
			$align   = get_theme_mod( 'global_header_align', 'center' );
			$context = 'global';
		}

		switch ( $align ) {
			case 'left':
				$class = 'page-hero-left';
				break;
			case 'right':
				$class = 'page-hero-right';
				break;
			case 'center':
			default:
				$class = 'page-hero-center';
				break;
		}

		return apply_filters( 'neto_section_align_class', $class, $context, $align );
	}
endif;



if ( ! function_exists( 'neto_get_align_choices' ) ) :
	function neto_get_align_choices() {
		return apply_filters( 'neto_align_choices', array(
			'left'   => esc_html__( 'Left', 'neto' ),
			'right'  => esc_html__( 'Right', 'neto' ),
			'center' => esc_html__( 'Center', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_align' ) ) :
	function neto_sanitize_align( $value ) {
		$choices = neto_get_align_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_align_default', 'left' );
	}
endif;

if ( ! function_exists( 'neto_get_header_style_choices' ) ) :
	function neto_get_header_style_choices() {
		return apply_filters( 'neto_header_style_choices', array(
			''            => esc_html__( 'Menu next to logo', 'neto' ),
			'center-menu' => esc_html__( 'Centered menu', 'neto' ),
			'center-logo' => esc_html__( 'Centered logo', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_header_style' ) ) :
	function neto_sanitize_header_style( $value ) {
		$choices = neto_get_header_style_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_header_style_default', 'center-menu' );
	}
endif;

if ( ! function_exists( 'neto_get_mobile_menu_choices' ) ) :
	function neto_get_mobile_menu_choices() {
		return apply_filters( 'neto_get_mobile_menu_choices', array(
			'primary_menu'   => esc_html__( 'Primary Menu', 'neto' ),
			'secondary_menu' => esc_html__( 'Secondary Menu', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_mobile_menu' ) ) :
	function neto_sanitize_mobile_menu( $value ) {
		$choices = neto_get_mobile_menu_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_mobile_menu_default', 'primary_menu' );
	}
endif;

if ( ! function_exists( 'neto_get_blog_layout_choices' ) ) :
	function neto_get_blog_layout_choices() {
		return apply_filters( 'neto_blog_layout_choices', array(
			''           => esc_html__( 'Right Sidebar', 'neto' ),
			'no-sidebar' => esc_html__( 'No Sidebar', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_blog_layout' ) ) :
	function neto_sanitize_blog_layout( $value ) {
		$choices = neto_get_blog_layout_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_blog_layout_default', '' );
	}
endif;

if ( ! function_exists( 'neto_get_shop_layout_choices' ) ) :
	function neto_get_shop_layout_choices() {
		return apply_filters( 'neto_shop_layout_choices', array(
			'left'  => esc_html__( 'Left Sidebar', 'neto' ),
			'right' => esc_html__( 'Right Sidebar', 'neto' ),
			'full'  => esc_html__( 'Full Width', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_shop_layout' ) ) :
	function neto_sanitize_shop_layout( $value ) {
		$choices = neto_get_shop_layout_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_shop_layout_default', 'left' );
	}
endif;

if ( ! function_exists( 'neto_get_shop_columns_choices' ) ) :
	function neto_get_shop_columns_choices() {
		$min = apply_filters( 'neto_shop_columns_min', 3 );
		$max = apply_filters( 'neto_shop_columns_max', 4 );

		$options = array();
		for ( $i = $min; $i <= $max; $i ++ ) {
			$options[ $i ] = esc_html( sprintf( _n( '%s Column', '%s Columns', $i, 'neto' ), $i ) );
		}

		return apply_filters( 'neto_shop_columns_choices', $options, $min, $max );
	}
endif;

if ( ! function_exists( 'neto_sanitize_shop_columns' ) ) :
	function neto_sanitize_shop_columns( $value ) {
		$value   = intval( $value );
		$choices = neto_get_shop_columns_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_shop_columns_default', 3 );
	}
endif;

if ( ! function_exists( 'neto_get_global_layout_choices' ) ) :
	function neto_get_global_layout_choices() {
		return apply_filters( 'neto_global_layout_choices', array(
			''      => esc_html__( 'Full Width', 'neto' ),
			'boxed' => esc_html__( 'Boxed', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_global_layout' ) ) :
	function neto_sanitize_global_layout( $value ) {
		$choices = neto_get_global_layout_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_global_layout_default', '' );
	}
endif;

if ( ! function_exists( 'neto_get_image_repeat_choices' ) ) :
	function neto_get_image_repeat_choices() {
		return apply_filters( 'neto_image_repeat_choices', array(
			'no-repeat' => esc_html__( 'No repeat', 'neto' ),
			'repeat'    => esc_html__( 'Tile', 'neto' ),
			'repeat-x'  => esc_html__( 'Tile Horizontally', 'neto' ),
			'repeat-y'  => esc_html__( 'Tile Vertically', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_image_repeat' ) ) :
	function neto_sanitize_image_repeat( $value ) {
		$choices = neto_get_image_repeat_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_image_repeat_default', 'no-repeat' );
	}
endif;

if ( ! function_exists( 'neto_get_image_position_x_choices' ) ) :
	function neto_get_image_position_x_choices() {
		return apply_filters( 'neto_image_position_x_choices', array(
			'left'   => esc_html__( 'Left', 'neto' ),
			'center' => esc_html__( 'Center', 'neto' ),
			'right'  => esc_html__( 'Right', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_image_position_x' ) ) :
	function neto_sanitize_image_position_x( $value ) {
		$choices = neto_get_image_position_x_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_image_position_x_default', 'center' );
	}
endif;

if ( ! function_exists( 'neto_get_image_position_y_choices' ) ) :
	function neto_get_image_position_y_choices() {
		return apply_filters( 'neto_image_position_y_choices', array(
			'top'    => esc_html__( 'Top', 'neto' ),
			'center' => esc_html__( 'Center', 'neto' ),
			'bottom' => esc_html__( 'Bottom', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_image_position_y' ) ) :
	function neto_sanitize_image_position_y( $value ) {
		$choices = neto_get_image_position_y_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_image_position_y_default', 'center' );
	}
endif;

if ( ! function_exists( 'neto_get_image_attachment_choices' ) ) :
	function neto_get_image_attachment_choices() {
		return apply_filters( 'neto_image_attachment_choices', array(
			'scroll' => esc_html__( 'Scroll', 'neto' ),
			'fixed'  => esc_html__( 'Fixed', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_image_attachment' ) ) :
	function neto_sanitize_image_attachment( $value ) {
		$choices = neto_get_image_attachment_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_image_attachment_default', 'scroll' );
	}
endif;

if ( ! function_exists( 'neto_get_hero_show_choices' ) ) :
	function neto_get_hero_show_choices() {
		return apply_filters( 'neto_hero_show_choices', array(
			''    => esc_html__( 'Default', 'neto' ),
			'yes' => esc_html__( 'Yes', 'neto' ),
			'no'  => esc_html__( 'No', 'neto' ),
		) );
	}
endif;

if ( ! function_exists( 'neto_sanitize_hero_show' ) ) :
	function neto_sanitize_hero_show( $value ) {
		$choices = neto_get_hero_show_choices();
		if ( array_key_exists( $value, $choices ) ) {
			return $value;
		}

		return apply_filters( 'neto_sanitize_hero_show_default', '' );
	}
endif;


if ( ! function_exists( 'neto_get_content_sidebar_classes' ) ) :
	function neto_get_content_sidebar_classes( $layout ) {
		$classes = array(
			'has_sidebar' => true,
			'content'     => '',
			'sidebar'     => '',
		);

		switch ( $layout ) {
			case 'left':
				$classes['has_sidebar'] = true;
				$classes['content']     = 'col-xl-9 push-xl-3 col-lg-8 push-lg-4 col-xs-12';
				$classes['sidebar']     = 'col-xl-3 pull-xl-9 col-lg-4 pull-lg-8 col-xs-12';
				break;
			case 'no-sidebar':
				$classes['has_sidebar'] = false;
				$classes['content']     = 'col-xl-8 offset-xl-2 col-lg-10 offset-lg-1 col-xs-12';
				$classes['sidebar']     = '';
				break;
			case 'right':
			default:
				$classes['has_sidebar'] = true;
				$classes['content']     = 'col-xl-9 col-lg-8 col-xs-12';
				$classes['sidebar']     = 'col-xl-3 col-lg-4 col-xs-12';
		}

		return apply_filters( 'neto_content_sidebar_classes', $classes, $layout );
	}
endif;

if ( ! function_exists( 'neto_get_shop_content_sidebar_classes' ) ) :
	function neto_get_shop_content_sidebar_classes( $layout ) {
		$classes = array(
			'has_sidebar' => true,
			'content'     => '',
			'sidebar'     => '',
		);

		switch ( $layout ) {
			case 'right':
				$classes['has_sidebar'] = true;
				$classes['content']     = 'col-xl-9 col-lg-8 col-xs-12';
				$classes['sidebar']     = 'col-xl-3 col-lg-4 col-xs-12';
				break;
			case 'full':
				$classes['has_sidebar'] = false;
				$classes['content']     = 'col-xs-12';
				$classes['sidebar']     = '';
				break;
			case 'left':
			default:
				$classes['has_sidebar'] = true;
				$classes['content']     = 'col-xl-9 push-xl-3 col-lg-8 push-lg-4 col-xs-12';
				$classes['sidebar']     = 'col-xl-3 pull-xl-9 col-lg-4 pull-lg-8 col-xs-12';
		}

		return apply_filters( 'neto_shop_content_sidebar_classes', $classes, $layout );
	}
endif;


// Only applies to WooCommerce Monster Widget
add_filter( 'wc-monster-widget-config', 'neto_wc_monster_widget_config' );
if ( ! function_exists( 'neto_wc_monster_widget_config' ) ) :
	function neto_wc_monster_widget_config( $widgets ) {
		$index_reviews = false;

		foreach ( $widgets as $index => $widget ) {
			if ( 'WC_Widget_Recent_Reviews' === $widget[0] ) {
				$index_reviews = $index;
			}
		}

		if ( false !== $index_reviews ) {
			$new_widget                = $widgets[ $index_reviews ];
			$new_widget[0]             = 'Neto_WC_Widget_Recent_Reviews';
			$widgets[ $index_reviews ] = $new_widget;
		}

		return $widgets;
	}
endif;


add_filter( 'tiny_mce_before_init', 'neto_insert_wp_editor_formats' );
if ( ! function_exists( 'neto_insert_wp_editor_formats' ) ) :
	function neto_insert_wp_editor_formats( $init_array ) {
		// Define the style_formats array
		$style_formats = array(
			// Each array child is a format with it's own settings
			array(
				'title'   => esc_html__( 'Styled Table', 'neto' ),
				'block'   => 'div',
				'classes' => 'table-styled',
				'wrapper' => true,
			),
		);
		// Insert the array, JSON ENCODED, into 'style_formats'
		$init_array['style_formats'] = wp_json_encode( $style_formats );

		return $init_array;
	}
endif;

add_filter( 'mce_buttons_2', 'neto_mce_buttons_2' );
if ( ! function_exists( 'neto_mce_buttons_2' ) ) :
	function neto_mce_buttons_2( $buttons ) {
		array_unshift( $buttons, 'styleselect' );

		return $buttons;
	}
endif;

add_filter( 'neto_posts_pagination_default_args', 'neto_posts_pagination_default_args' );
if ( ! function_exists( 'neto_posts_pagination_default_args' ) ) :
	function neto_posts_pagination_default_args( $args ) {
		$args['prev_text'] = sprintf( '<i class="fa fa-long-arrow-left"></i><span class="screen-reader-text">%s</span>',
			esc_html__( 'Older posts', 'neto' )
		);

		$args['next_text'] = sprintf( '<span class="screen-reader-text">%s</span><i class="fa fa-long-arrow-right"></i>',
			esc_html__( 'Newer posts', 'neto' )
		);

		return $args;
	}
endif;


add_filter( 'body_class', 'neto_body_classes' );
if ( ! function_exists( 'neto_body_classes' ) ) :
	function neto_body_classes( $classes ) {
		if ( 'boxed' === get_theme_mod( 'layout_global' ) ) {
			$classes[] = 'boxed';
		}

		return $classes;
	}
endif;


add_filter( 'wp_link_pages_args', 'neto_wp_link_pages_args' );
if ( ! function_exists( 'neto_wp_link_pages_args' ) ) :
	function neto_wp_link_pages_args( $params ) {
		$params['before']      = '<div class="page-links"><span class="page-links-title">' . esc_html__( 'Pages:', 'neto' ) . '</span>';
		$params['after']       = '</div>';
		$params['link_before'] = '<span>';
		$params['link_after']  = '</span>';

		return $params;
	}
endif;



if ( ! defined( 'NETO_WHITELABEL' ) || false === (bool) NETO_WHITELABEL ) {
	add_filter( 'pt-ocdi/import_files', 'neto_ocdi_import_files' );
	add_action( 'pt-ocdi/after_import', 'neto_ocdi_after_import_setup' );
}

add_filter( 'pt-ocdi/timeout_for_downloading_import_file', 'neto_ocdi_download_timeout' );
function neto_ocdi_download_timeout( $timeout ) {
	return 60;
}

function neto_ocdi_import_files( $files ) {
	if ( ! defined( 'NETO_NAME' ) ) {
		define( 'NETO_NAME', 'neto' );
	}

	$demo_dir_url = untrailingslashit( apply_filters( 'neto_ocdi_demo_dir_url', 'https://www.cssigniter.com/sample_content/' . NETO_NAME ) );

	// When having more that one predefined imports, set a preview image, preview URL, and categories for isotope-style filtering.
	$new_files = array(
		array(
			'import_file_name'           => esc_html__( 'Demo Import', 'neto' ),
			'import_file_url'            => $demo_dir_url . '/content.xml',
			'import_widget_file_url'     => $demo_dir_url . '/widgets.wie',
			'import_customizer_file_url' => $demo_dir_url . '/customizer.dat',
		),
	);

	return array_merge( $files, $new_files );
}

function neto_ocdi_after_import_setup() {
	// Set up nav menus.
	$main_menu   = get_term_by( 'name', 'Main', 'nav_menu' );
	$footer_menu = get_term_by( 'name', 'Footer', 'nav_menu' );

	set_theme_mod( 'nav_menu_locations', array(
		'main_menu'   => $main_menu->term_id,
		'footer_menu' => $footer_menu->term_id,
	) );

	// Set up home and blog pages.
	$front_page_id = get_page_by_title( 'Home - V01' );
	$blog_page_id  = get_page_by_title( 'Blog' );

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );
}

add_action( 'init', 'neto_migrate_custom_css_to_customizer' );
function neto_migrate_custom_css_to_customizer() {
	if ( ! is_admin() || wp_doing_ajax() || ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) ) {
		return;
	}

	remove_theme_mod( 'custom_css_migrated' );

	$migrated = get_theme_mod( 'custom_css_migrated', false );

	if ( $migrated || ! function_exists( 'wp_update_custom_css_post' ) ) {
		return;
	}

	// Migrate any existing theme CSS to the core option added in WordPress 4.7.
	$css = get_theme_mod( 'custom_css', '' );
	if ( $css ) {
		// Preserve any CSS already added to the core option.
		$core_css = wp_get_custom_css();

		$return = wp_update_custom_css_post( $core_css .
			PHP_EOL . PHP_EOL .
			"/* Migrated CSS from the theme's old custom CSS setting. */" .
			PHP_EOL .
			html_entity_decode( $css )
		);

		if ( ! is_wp_error( $return ) ) {
			// Remove the old option, so that the CSS is stored in only one place moving forward.
			set_theme_mod( 'custom_css', '' );
			set_theme_mod( 'custom_css_migrated', true );
		}
	}
}

/**
 * Common theme features.
 */
require_once get_theme_file_path( '/common/common.php' );

