<?php
add_action( 'customize_register', 'neto_customize_register', 100 );
/**
 * Registers all theme-related options to the Customizer.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function neto_customize_register( $wpc ) {

	$wpc->add_section( 'header_appearance', array(
		'title'    => esc_html_x( 'Header', 'customizer section title', 'neto' ),
		'priority' => 1,
	) );

	$wpc->get_panel( 'nav_menus' )->priority = 10;

	$wpc->add_section( 'layout', array(
		'title'    => esc_html_x( 'Layout Options', 'customizer section title', 'neto' ),
		'priority' => 20,
	) );

	$wpc->add_section( 'listing', array(
		'title'    => esc_html_x( 'Post Listing Options', 'customizer section title', 'neto' ),
		'priority' => 30,
	) );

	$wpc->add_section( 'single_post', array(
		'title'       => esc_html_x( 'Posts Options', 'customizer section title', 'neto' ),
		'description' => esc_html__( 'These options affect your individual posts.', 'neto' ),
		'priority'    => 40,
	) );

	$wpc->add_panel( 'woocommerce', array(
		'title'       => esc_html_x( 'WooCommerce', 'customizer section title', 'neto' ),
		'description' => esc_html__( 'Requires WooCommerce to be installed and active.', 'neto' ),
		'priority'    => 50,
	) );

	$wpc->add_section( 'woocommerce_shop', array(
		'title'       => esc_html_x( 'Shop', 'customizer section title', 'neto' ),
		'panel'       => 'woocommerce',
		'description' => esc_html__( 'Options affecting the shop listing pages.', 'neto' ),
	) );

	$wpc->add_section( 'woocommerce_product', array(
		'title'       => esc_html_x( 'Product', 'customizer section title', 'neto' ),
		'panel'       => 'woocommerce',
		'description' => esc_html__( 'Options affecting the single product pages.', 'neto' ),
	) );

	$wpc->add_panel( 'theme_colors', array(
		'title'    => esc_html_x( 'Colors', 'customizer section title', 'neto' ),
		'priority' => 60,
	) );

	$wpc->get_section( 'colors' )->title    = esc_html__( 'Global', 'neto' );
	$wpc->get_section( 'colors' )->priority = 60;
	$wpc->get_section( 'colors' )->panel    = 'theme_colors';

	$wpc->add_section( 'colors_header', array(
		'title'    => esc_html_x( 'Header', 'customizer section title', 'neto' ),
		'panel'    => 'theme_colors',
	) );

	$wpc->add_section( 'colors_footer', array(
		'title'    => esc_html_x( 'Footer', 'customizer section title', 'neto' ),
		'panel'    => 'theme_colors',
	) );

	$wpc->add_section( 'colors_sidebar', array(
		'title'    => esc_html_x( 'Sidebar', 'customizer section title', 'neto' ),
		'panel'    => 'theme_colors',
	) );

	$wpc->add_section( 'typography', array(
		'title'    => esc_html_x( 'Typography Options', 'customizer section title', 'neto' ),
		'priority' => 65,
	) );

	// The following line doesn't work in a some PHP versions. Apparently, get_panel( 'widgets' ) returns an array,
	// therefore a cast to object is needed. http://wordpress.stackexchange.com/questions/160987/warning-creating-default-object-when-altering-customize-panels
	//$wpc->get_panel( 'widgets' )->priority = 50;
	$panel_widgets = (object) $wpc->get_panel( 'widgets' );
	$panel_widgets->priority = 70;

	$wpc->add_section( 'social', array(
		'title'       => esc_html_x( 'Social Networks', 'customizer section title', 'neto' ),
		'description' => esc_html__( 'Enter your social network URLs. Leaving a URL empty will hide its respective icon.', 'neto' ),
		'priority'    => 80,
	) );


	$wpc->add_section( 'footer', array(
		'title'    => esc_html_x( 'Footer Options', 'customizer section title', 'neto' ),
		'priority' => 100,
	) );

	// Section 'static_front_page' is not defined when there are no pages.
	if ( get_pages() ) {
		$wpc->get_section( 'static_front_page' )->priority = 110;
	}

	$wpc->add_section( 'other', array(
		'title'       => esc_html_x( 'Other', 'customizer section title', 'neto' ),
		'description' => esc_html__( 'Other options affecting the whole site.', 'neto' ),
		'priority'    => 120,
	) );



	//
	// Group options by registering the setting first, and the control right after.
	//

	// Needed by the category and shop image descriptions.
	global $_wp_additional_image_sizes;
	$size      = $_wp_additional_image_sizes['neto_hero'];
	$hero_size = $size['width'] . 'x' . $size['height'];


	//
	// Header Appearance
	//
	$wpc->add_setting( 'header_style', array(
		'default'           => 'center-menu',
		'sanitize_callback' => 'neto_sanitize_header_style',
	) );
	$wpc->add_control( 'header_style', array(
		'type'    => 'select',
		'section' => 'header_appearance',
		'label'   => esc_html__( 'Header style', 'neto' ),
		'choices' => neto_get_header_style_choices(),
	) );

	$wpc->add_setting( 'mobile_menu', array(
		'default'           => 'primary_menu',
		'sanitize_callback' => 'neto_sanitize_mobile_menu',
	) );
	$wpc->add_control( 'mobile_menu', array(
		'type'    => 'select',
		'section' => 'header_appearance',
		'label'   => esc_html__( 'Mobile Menu', 'neto' ),
		'choices' => neto_get_mobile_menu_choices(),
	) );

	$wpc->add_setting( 'header_sticky', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'header_sticky', array(
		'type'    => 'checkbox',
		'section' => 'header_appearance',
		'label'   => esc_html__( 'Sticky header.', 'neto' ),
	) );

	$wpc->add_setting( 'header_account', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'header_account', array(
		'type'        => 'checkbox',
		'section'     => 'header_appearance',
		'label'       => esc_html__( 'Show Account / Login / Register link.', 'neto' ),
		'description' => esc_html__( 'Requires WooCommerce to be installed and active.', 'neto' ),
	) );

	$wpc->add_setting( 'header_cart', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'header_cart', array(
		'type'        => 'checkbox',
		'section'     => 'header_appearance',
		'label'       => esc_html__( 'Show shopping cart icon.', 'neto' ),
		'description' => esc_html__( 'Requires WooCommerce to be installed and active.', 'neto' ),
	) );

	$wpc->add_setting( 'header_search', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'header_search', array(
		'type'        => 'checkbox',
		'section'     => 'header_appearance',
		'label'       => esc_html__( 'Show search icon.', 'neto' ),
		'description' => esc_html__( 'Requires WooCommerce to be installed and active.', 'neto' ),
	) );



	//
	// Layout
	//
	$wpc->add_setting( 'layout_global', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_global_layout',
	) );
	$wpc->add_control( 'layout_global', array(
		'type'        => 'select',
		'section'     => 'layout',
		'label'       => esc_html__( 'Global layout', 'neto' ),
		'description' => esc_html__( 'Limits the website\'s span at a fixed width giving a boxed appearance.', 'neto' ),
		'choices'     => neto_get_global_layout_choices(),
	) );

	$wpc->add_setting( 'layout_blog', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_blog_layout',
	) );
	$wpc->add_control( 'layout_blog', array(
		'type'        => 'select',
		'section'     => 'layout',
		'label'       => esc_html__( 'Blog layout', 'neto' ),
		'description' => esc_html__( 'Affects the blog listing and single posts.', 'neto' ),
		'choices'     => neto_get_blog_layout_choices(),
	) );

	$wpc->add_setting( 'layout_other', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_blog_layout',
	) );
	$wpc->add_control( 'layout_other', array(
		'type'        => 'select',
		'section'     => 'layout',
		'label'       => esc_html__( 'Other pages layout', 'neto' ),
		'description' => esc_html__( 'Affects category and tag listings, 404, search, etc.', 'neto' ),
		'choices'     => neto_get_blog_layout_choices(),
	) );

	$wpc->add_setting( 'excerpt_length', array(
		'default'           => 55,
		'sanitize_callback' => 'absint',
	) );
	$wpc->add_control( 'excerpt_length', array(
		'type'        => 'number',
		'input_attrs' => array(
			'min'  => 10,
			'step' => 1,
		),
		'section'     => 'layout',
		'label'       => esc_html__( 'Automatically generated excerpt length (in words)', 'neto' ),
	) );

	$wpc->add_setting( 'pagination_method', array(
		'default'           => 'numbers',
		'sanitize_callback' => 'neto_sanitize_pagination_method',
	) );
	$wpc->add_control( 'pagination_method', array(
		'type'    => 'select',
		'section' => 'layout',
		'label'   => esc_html__( 'Pagination method', 'neto' ),
		'choices' => array(
			'numbers' => esc_html_x( 'Numbered links', 'pagination method', 'neto' ),
			'text'    => esc_html_x( '"Previous - Next" links', 'pagination method', 'neto' ),
		),
	) );



	//
	// Post Listing
	//
	$wpc->add_setting( 'listing_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'listing_featured', array(
		'type'    => 'checkbox',
		'section' => 'listing',
		'label'   => esc_html__( 'Show featured images.', 'neto' ),
	) );

	$wpc->add_setting( 'category_hero_show', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'category_hero_show', array(
		'type'        => 'checkbox',
		'section'     => 'listing',
		'label'       => esc_html__( 'Show hero section.', 'neto' ),
		'description' => esc_html__( 'Applies to categories and tags listings.', 'neto' ),
	) );

	$wpc->add_setting( 'category_header_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'category_header_color', array(
		'section' => 'listing',
		'label'   => esc_html__( 'Categories page hero text color', 'neto' ),
	) ) );

	$wpc->add_setting( 'category_header_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'category_header_bg_color', array(
		'section' => 'listing',
		'label'   => esc_html__( 'Categories page hero background color', 'neto' ),
	) ) );

	$wpc->add_setting( 'category_header_image', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( new WP_Customize_Image_Control( $wpc, 'category_header_image', array(
		'section'     => 'listing',
		'label'       => esc_html__( 'Categories page hero image', 'neto' ),
		'description' => esc_html( sprintf( __( 'Recommended size of at least %s pixels.', 'neto' ), $hero_size ) ),
	) ) );

	$wpc->add_setting( 'category_header_image_repeat', array(
		'default'           => 'no-repeat',
		'sanitize_callback' => 'neto_sanitize_image_repeat',
	) );
	$wpc->add_control( 'category_header_image_repeat', array(
		'type'    => 'radio',
		'section' => 'listing',
		'label'   => esc_html__( 'Categories page hero image repeat', 'neto' ),
		'choices' => neto_get_image_repeat_choices(),
	) );

	$wpc->add_setting( 'category_header_image_position_x', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_x',
	) );
	$wpc->add_control( 'category_header_image_position_x', array(
		'type'    => 'radio',
		'section' => 'listing',
		'label'   => esc_html__( 'Categories page hero image horizontal position', 'neto' ),
		'choices' => neto_get_image_position_x_choices(),
	) );

	$wpc->add_setting( 'category_header_image_position_y', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_y',
	) );
	$wpc->add_control( 'category_header_image_position_y', array(
		'type'    => 'radio',
		'section' => 'listing',
		'label'   => esc_html__( 'Categories page hero image vertical position', 'neto' ),
		'choices' => neto_get_image_position_y_choices(),
	) );

	$wpc->add_setting( 'category_header_image_attachment', array(
		'default'           => 'scroll',
		'sanitize_callback' => 'neto_sanitize_image_attachment',
	) );
	$wpc->add_control( 'category_header_image_attachment', array(
		'type'    => 'radio',
		'section' => 'listing',
		'label'   => esc_html__( 'Categories page hero image attachment', 'neto' ),
		'choices' => neto_get_image_attachment_choices(),
	) );

	$wpc->add_setting( 'category_header_image_cover', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'category_header_image_cover', array(
		'type'    => 'checkbox',
		'section' => 'listing',
		'label'   => esc_html__( 'Scale the image to cover the category page hero area.', 'neto' ),
	) );

	$wpc->add_setting( 'category_header_align', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_align',
	) );
	$wpc->add_control( 'category_header_align', array(
		'type'        => 'select',
		'section'     => 'listing',
		'label'       => esc_html__( 'Categories page hero align', 'neto' ),
		'choices'     => neto_get_align_choices(),
	) );



	//
	// Global colors
	//
	$wpc->get_control( 'background_image' )->section      = 'colors';
	$wpc->get_control( 'background_repeat' )->section     = 'colors';
	$wpc->get_control( 'background_attachment' )->section = 'colors';
	if ( ! is_null( $wpc->get_control( 'background_position_x' ) ) ) {
		$wpc->get_control( 'background_position_x' )->section = 'colors';
	} else {
		$wpc->get_control( 'background_position' )->section = 'colors';
		$wpc->get_control( 'background_preset' )->section   = 'colors';
		$wpc->get_control( 'background_size' )->section     = 'colors';
	}

	$wpc->add_setting( 'body_background_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'body_background_bg_color', array(
		'section'     => 'colors',
		'label'       => esc_html__( 'Body background color', 'neto' ),
		'description' => wp_kses( __( 'Requires <strong>Layout > Global layout</strong> to be set on <strong>Boxed</strong>.', 'neto' ), neto_get_allowed_tags( 'guide' ) ),
	) ) );

	$wpc->add_setting( 'body_background_image', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( new WP_Customize_Image_Control( $wpc, 'body_background_image', array(
		'section'     => 'colors',
		'label'       => esc_html__( 'Body background image', 'neto' ),
		'description' => wp_kses( __( 'Requires <strong>Layout > Global layout</strong> to be set on <strong>Boxed</strong>.', 'neto' ), neto_get_allowed_tags( 'guide' ) ),
	) ) );

	$wpc->add_setting( 'body_background_image_repeat', array(
		'default'           => 'no-repeat',
		'sanitize_callback' => 'neto_sanitize_image_repeat',
	) );
	$wpc->add_control( 'body_background_image_repeat', array(
		'type'    => 'radio',
		'section' => 'colors',
		'label'   => esc_html__( 'Body background image repeat', 'neto' ),
		'choices' => neto_get_image_repeat_choices(),
	) );

	$wpc->add_setting( 'body_background_image_position_x', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_x',
	) );
	$wpc->add_control( 'body_background_image_position_x', array(
		'type'    => 'radio',
		'section' => 'colors',
		'label'   => esc_html__( 'Body background image horizontal position', 'neto' ),
		'choices' => neto_get_image_position_x_choices(),
	) );

	$wpc->add_setting( 'body_background_image_position_y', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_y',
	) );
	$wpc->add_control( 'body_background_image_position_y', array(
		'type'    => 'radio',
		'section' => 'colors',
		'label'   => esc_html__( 'Body background image vertical position', 'neto' ),
		'choices' => neto_get_image_position_y_choices(),
	) );

	$wpc->add_setting( 'body_background_image_attachment', array(
		'default'           => 'scroll',
		'sanitize_callback' => 'neto_sanitize_image_attachment',
	) );
	$wpc->add_control( 'body_background_image_attachment', array(
		'type'    => 'radio',
		'section' => 'colors',
		'label'   => esc_html__( 'Body background image attachment', 'neto' ),
		'choices' => neto_get_image_attachment_choices(),
	) );

	$wpc->add_setting( 'body_background_image_cover', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'body_background_image_cover', array(
		'type'    => 'checkbox',
		'section' => 'colors',
		'label'   => esc_html__( 'Scale the image to cover the visible body area.', 'neto' ),
	) );

	$wpc->add_setting( 'global_header_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_header_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Page hero text color', 'neto' ),
	) ) );

	$wpc->add_setting( 'global_header_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'global_header_bg_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Page hero background color', 'neto' ),
	) ) );

	$wpc->add_setting( 'global_header_image', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( new WP_Customize_Image_Control( $wpc, 'global_header_image', array(
		'section'     => 'colors',
		'label'       => esc_html__( 'Page hero image', 'neto' ),
		'description' => esc_html( sprintf( __( 'Recommended size of at least %s pixels.', 'neto' ), $hero_size ) ),
	) ) );

	$wpc->add_setting( 'global_header_image_repeat', array(
		'default'           => 'no-repeat',
		'sanitize_callback' => 'neto_sanitize_image_repeat',
	) );
	$wpc->add_control( 'global_header_image_repeat', array(
		'type'    => 'radio',
		'section' => 'colors',
		'label'   => esc_html__( 'Page hero image repeat', 'neto' ),
		'choices' => neto_get_image_repeat_choices(),
	) );

	$wpc->add_setting( 'global_header_image_position_x', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_x',
	) );
	$wpc->add_control( 'global_header_image_position_x', array(
		'type'    => 'radio',
		'section' => 'colors',
		'label'   => esc_html__( 'Page hero image horizontal position', 'neto' ),
		'choices' => neto_get_image_position_x_choices(),
	) );

	$wpc->add_setting( 'global_header_image_position_y', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_y',
	) );
	$wpc->add_control( 'global_header_image_position_y', array(
		'type'    => 'radio',
		'section' => 'colors',
		'label'   => esc_html__( 'Page hero image vertical position', 'neto' ),
		'choices' => neto_get_image_position_y_choices(),
	) );

	$wpc->add_setting( 'global_header_image_attachment', array(
		'default'           => 'scroll',
		'sanitize_callback' => 'neto_sanitize_image_attachment',
	) );
	$wpc->add_control( 'global_header_image_attachment', array(
		'type'    => 'radio',
		'section' => 'colors',
		'label'   => esc_html__( 'Page hero image attachment', 'neto' ),
		'choices' => neto_get_image_attachment_choices(),
	) );

	$wpc->add_setting( 'global_header_image_cover', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'global_header_image_cover', array(
		'type'    => 'checkbox',
		'section' => 'colors',
		'label'   => esc_html__( 'Scale the image to cover the page hero area.', 'neto' ),
	) );

	$wpc->add_setting( 'global_header_align', array(
		'default'           => 'left',
		'sanitize_callback' => 'neto_sanitize_align',
	) );
	$wpc->add_control( 'global_header_align', array(
		'type'    => 'select',
		'section' => 'colors',
		'label'   => esc_html__( 'Page hero align', 'neto' ),
		'choices' => neto_get_align_choices(),
	) );

	$wpc->add_setting( 'site_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_text_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Text Color', 'neto' ),
	) ) );

	$wpc->add_setting( 'site_text_color_dark', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_text_color_dark', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Secondary text color (darker)', 'neto' ),
	) ) );

	$wpc->add_setting( 'site_accent_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_accent_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Accent color', 'neto' ),
	) ) );

	$wpc->add_setting( 'site_text_on_accent_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_text_on_accent_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Text color on accent background', 'neto' ),
	) ) );

	$wpc->add_setting( 'site_border_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_border_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Border color', 'neto' ),
	) ) );

	$wpc->add_setting( 'site_light_grey_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'site_light_grey_bg_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Light grey backgrounds', 'neto' ),
	) ) );

	$wpc->add_setting( 'button_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'button_bg_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Button background color', 'neto' ),
	) ) );

	$wpc->add_setting( 'button_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'button_text_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Button text color', 'neto' ),
	) ) );

	$wpc->add_setting( 'button_hover_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'button_hover_bg_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Button hover background color', 'neto' ),
	) ) );

	$wpc->add_setting( 'button_hover_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'button_hover_text_color', array(
		'section' => 'colors',
		'label'   => esc_html__( 'Button hover text color', 'neto' ),
	) ) );



	//
	// Header colors
	//
	$wpc->add_setting( 'head_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'head_bg_color', array(
		'section' => 'colors_header',
		'label'   => esc_html__( 'Header background color', 'neto' ),
	) ) );

	$wpc->add_setting( 'head_image', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( new WP_Customize_Image_Control( $wpc, 'head_image', array(
		'section'     => 'colors_header',
		'label'       => esc_html__( 'Header image', 'neto' ),
		'description' => esc_html( sprintf( __( 'Recommended size of at least %s pixels, depending on the height of your header.', 'neto' ), '1920x100' ) ),
	) ) );

	$wpc->add_setting( 'head_image_repeat', array(
		'default'           => 'no-repeat',
		'sanitize_callback' => 'neto_sanitize_image_repeat',
	) );
	$wpc->add_control( 'head_image_repeat', array(
		'type'    => 'radio',
		'section' => 'colors_header',
		'label'   => esc_html__( 'Header image repeat', 'neto' ),
		'choices' => neto_get_image_repeat_choices(),
	) );

	$wpc->add_setting( 'head_image_position_x', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_x',
	) );
	$wpc->add_control( 'head_image_position_x', array(
		'type'    => 'radio',
		'section' => 'colors_header',
		'label'   => esc_html__( 'Header image horizontal position', 'neto' ),
		'choices' => neto_get_image_position_x_choices(),
	) );

	$wpc->add_setting( 'head_image_position_y', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_y',
	) );
	$wpc->add_control( 'head_image_position_y', array(
		'type'    => 'radio',
		'section' => 'colors_header',
		'label'   => esc_html__( 'Header image vertical position', 'neto' ),
		'choices' => neto_get_image_position_y_choices(),
	) );

	$wpc->add_setting( 'head_image_attachment', array(
		'default'           => 'scroll',
		'sanitize_callback' => 'neto_sanitize_image_attachment',
	) );
	$wpc->add_control( 'head_image_attachment', array(
		'type'    => 'radio',
		'section' => 'colors_header',
		'label'   => esc_html__( 'Header image attachment', 'neto' ),
		'choices' => neto_get_image_attachment_choices(),
	) );

	$wpc->add_setting( 'head_image_cover', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'head_image_cover', array(
		'type'    => 'checkbox',
		'section' => 'colors_header',
		'label'   => esc_html__( 'Scale the image to cover the header area.', 'neto' ),
	) );

	$wpc->add_setting( 'head_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'head_text_color', array(
		'section' => 'colors_header',
		'label'   => esc_html__( 'Main text color', 'neto' ),
	) ) );

	$wpc->add_setting( 'head_subnav_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'head_subnav_bg_color', array(
		'section' => 'colors_header',
		'label'   => esc_html__( 'Subnavigation background', 'neto' ),
	) ) );

	$wpc->add_setting( 'head_subnav_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'head_subnav_text_color', array(
		'section' => 'colors_header',
		'label'   => esc_html__( 'Subnavigation text color', 'neto' ),
	) ) );

	$wpc->add_setting( 'head_subnav_text_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'head_subnav_text_hover_color', array(
		'section' => 'colors_header',
		'label'   => esc_html__( 'Subnavigation hover &amp; active text color', 'neto' ),
	) ) );

	$wpc->add_setting( 'head_subnav_border_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'head_subnav_border_color', array(
		'section' => 'colors_header',
		'label'   => esc_html__( 'Subnavigation border color', 'neto' ),
	) ) );



	//
	// Footer colors
	//
	$wpc->add_setting( 'footer_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'footer_bg_color', array(
		'section' => 'colors_footer',
		'label'   => esc_html__( 'Footer strip background color', 'neto' ),
	) ) );

	$wpc->add_setting( 'footer_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'footer_text_color', array(
		'section' => 'colors_footer',
		'label'   => esc_html__( 'Footer strip text color', 'neto' ),
	) ) );



	//
	// Sidebar colors
	//
	$wpc->add_setting( 'sidebar_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_bg_color', array(
		'section' => 'colors_sidebar',
		'label'   => esc_html__( 'Background color', 'neto' ),
	) ) );

	$wpc->add_setting( 'sidebar_text_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_text_color', array(
		'section' => 'colors_sidebar',
		'label'   => esc_html__( 'Text color', 'neto' ),
	) ) );

	$wpc->add_setting( 'sidebar_link_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_link_color', array(
		'section' => 'colors_sidebar',
		'label'   => esc_html__( 'Link color', 'neto' ),
	) ) );

	$wpc->add_setting( 'sidebar_link_hover_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_link_hover_color', array(
		'section' => 'colors_sidebar',
		'label'   => esc_html__( 'Link hover color', 'neto' ),
	) ) );

	$wpc->add_setting( 'sidebar_border_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_border_color', array(
		'section' => 'colors_sidebar',
		'label'   => esc_html__( 'Border color', 'neto' ),
	) ) );

	$wpc->add_setting( 'sidebar_widget_title_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'sidebar_widget_title_color', array(
		'section' => 'colors_sidebar',
		'label'   => esc_html__( 'Widget titles color', 'neto' ),
	) ) );



	//
	// Typography
	//
	$wpc->add_setting( 'h1_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h1_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Content H1 size', 'neto' ),
	) );

	$wpc->add_setting( 'h2_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h2_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Content H2 size', 'neto' ),
	) );

	$wpc->add_setting( 'h3_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h3_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Content H3 size', 'neto' ),
	) );

	$wpc->add_setting( 'h4_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h4_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Content H4 size', 'neto' ),
	) );

	$wpc->add_setting( 'h5_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h5_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Content H5 size', 'neto' ),
	) );

	$wpc->add_setting( 'h6_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'h6_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Content H6 size', 'neto' ),
	) );

	$wpc->add_setting( 'body_text_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'body_text_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Content body text size', 'neto' ),
	) );

	$wpc->add_setting( 'widgets_title_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'widgets_title_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Widgets title size', 'neto' ),
	) );

	$wpc->add_setting( 'widgets_text_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'widgets_text_size', array(
		'type'    => 'number',
		'section' => 'typography',
		'label'   => esc_html__( 'Widgets text size', 'neto' ),
	) );

	$wpc->add_setting( 'lowercase_section_titles', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'lowercase_section_titles', array(
		'type'    => 'checkbox',
		'section' => 'typography',
		'label'   => esc_html__( 'Lowercase section titles', 'neto' ),
	) );

	$wpc->add_setting( 'lowercase_widget_titles', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'lowercase_widget_titles', array(
		'type'    => 'checkbox',
		'section' => 'typography',
		'label'   => esc_html__( 'Lowercase widget and product titles', 'neto' ),
	) );



	//
	// Social
	//
	$wpc->add_setting( 'social_target', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'social_target', array(
		'type'    => 'checkbox',
		'section' => 'social',
		'label'   => esc_html__( 'Open social and sharing links in a new tab.', 'neto' ),
	) );

	$networks = neto_get_social_networks();

	foreach ( $networks as $network ) {
		$wpc->add_setting( 'social_' . $network['name'], array(
			'default'           => '',
			'sanitize_callback' => 'esc_url_raw',
		) );
		$wpc->add_control( 'social_' . $network['name'], array(
			'type'    => 'url',
			'section' => 'social',
			'label'   => esc_html( sprintf( _x( '%s URL', 'social network url', 'neto' ), $network['label'] ) ),
		) );
	}

	$wpc->add_setting( 'rss_feed', array(
		'default'           => get_bloginfo( 'rss2_url' ),
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( 'rss_feed', array(
		'type'    => 'url',
		'section' => 'social',
		'label'   => esc_html__( 'RSS Feed', 'neto' ),
	) );



	//
	// Single Post
	//
	$wpc->add_setting( 'single_featured', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_featured', array(
		'type'        => 'checkbox',
		'section'     => 'single_post',
		'label'       => esc_html__( 'Show featured image.', 'neto' ),
	) );

	$wpc->add_setting( 'single_categories', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_categories', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show categories.', 'neto' ),
	) );

	$wpc->add_setting( 'single_tags', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_tags', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show tags.', 'neto' ),
	) );

	$wpc->add_setting( 'single_comments', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_comments', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show comments.', 'neto' ),
	) );

	$wpc->add_setting( 'single_authorbox', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_authorbox', array(
		'type'        => 'checkbox',
		'section'     => 'single_post',
		'label'       => esc_html__( 'Show author box.', 'neto' ),
		'description' => wp_kses( __( 'Display your biographic info. Each author needs to fill it in from <strong>Users > Your Profile > Biographic info</strong>', 'neto' ), neto_get_allowed_tags() ),
	) );

	$wpc->add_setting( 'single_post_navigation', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_post_navigation', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show previous / next posts.', 'neto' ),
	) );

	$wpc->add_setting( 'single_related', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'single_related', array(
		'type'    => 'checkbox',
		'section' => 'single_post',
		'label'   => esc_html__( 'Show related posts.', 'neto' ),
	) );

	$wpc->add_setting( 'single_related_title', array(
		'default'           => esc_html__( 'You might also like', 'neto' ),
		'sanitize_callback' => 'sanitize_text_field',
	) );
	$wpc->add_control( 'single_related_title', array(
		'type'    => 'text',
		'section' => 'single_post',
		'label'   => esc_html__( 'Related Posts section title', 'neto' ),
	) );



	//
	// WooCommerce Shop
	//
	$wpc->add_setting( 'woocommerce_shop_hero_show', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_shop_hero_show', array(
		'type'        => 'checkbox',
		'section'     => 'woocommerce_shop',
		'label'       => esc_html__( 'Show hero section in shop.', 'neto' ),
		'description' => esc_html__( 'Applies to the main shop page.', 'neto' ),
	) );

	$wpc->add_setting( 'woocommerce_tax_hero_show', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_tax_hero_show', array(
		'type'        => 'checkbox',
		'section'     => 'woocommerce_shop',
		'label'       => esc_html__( 'Show hero section in listings.', 'neto' ),
		'description' => esc_html__( 'Applies to product categories and product tags listings.', 'neto' ),
	) );

	$wpc->add_setting( 'woocommerce_shop_header_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'woocommerce_shop_header_color', array(
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Page hero text color', 'neto' ),
	) ) );

	$wpc->add_setting( 'woocommerce_shop_header_bg_color', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_hex_color',
	) );
	$wpc->add_control( new WP_Customize_Color_Control( $wpc, 'woocommerce_shop_header_bg_color', array(
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Page hero background color', 'neto' ),
	) ) );

	$wpc->add_setting( 'woocommerce_shop_header_image', array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wpc->add_control( new WP_Customize_Image_Control( $wpc, 'woocommerce_shop_header_image', array(
		'section'     => 'woocommerce_shop',
		'label'       => esc_html__( 'Page hero image', 'neto' ),
		'description' => esc_html( sprintf( __( 'Recommended size of at least %s pixels.', 'neto' ), $hero_size ) ),
	) ) );

	$wpc->add_setting( 'woocommerce_shop_header_image_repeat', array(
		'default'           => 'no-repeat',
		'sanitize_callback' => 'neto_sanitize_image_repeat',
	) );
	$wpc->add_control( 'woocommerce_shop_header_image_repeat', array(
		'type'    => 'radio',
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Page hero image repeat', 'neto' ),
		'choices' => neto_get_image_repeat_choices(),
	) );

	$wpc->add_setting( 'woocommerce_shop_header_image_position_x', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_x',
	) );
	$wpc->add_control( 'woocommerce_shop_header_image_position_x', array(
		'type'    => 'radio',
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Page hero image horizontal position', 'neto' ),
		'choices' => neto_get_image_position_x_choices(),
	) );

	$wpc->add_setting( 'woocommerce_shop_header_image_position_y', array(
		'default'           => 'center',
		'sanitize_callback' => 'neto_sanitize_image_position_y',
	) );
	$wpc->add_control( 'woocommerce_shop_header_image_position_y', array(
		'type'    => 'radio',
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Page hero image vertical position', 'neto' ),
		'choices' => neto_get_image_position_y_choices(),
	) );

	$wpc->add_setting( 'woocommerce_shop_header_image_attachment', array(
		'default'           => 'scroll',
		'sanitize_callback' => 'neto_sanitize_image_attachment',
	) );
	$wpc->add_control( 'woocommerce_shop_header_image_attachment', array(
		'type'    => 'radio',
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Page hero image attachment', 'neto' ),
		'choices' => neto_get_image_attachment_choices(),
	) );

	$wpc->add_setting( 'woocommerce_shop_header_image_cover', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_shop_header_image_cover', array(
		'type'    => 'checkbox',
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Scale the image to cover the page hero area.', 'neto' ),
	) );

	$wpc->add_setting( 'woocommerce_shop_header_align', array(
		'default'           => 'left',
		'sanitize_callback' => 'neto_sanitize_align',
	) );
	$wpc->add_control( 'woocommerce_shop_header_align', array(
		'type'    => 'select',
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Page hero align', 'neto' ),
		'choices' => neto_get_align_choices(),
	) );

	$wpc->add_setting( 'woocommerce_shop_layout', array(
		'default'           => 'left',
		'sanitize_callback' => 'neto_sanitize_shop_layout',
	) );
	$wpc->add_control( 'woocommerce_shop_layout', array(
		'type'    => 'select',
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Shop layout', 'neto' ),
		'choices' => neto_get_shop_layout_choices(),
	) );

	$wpc->add_setting( 'woocommerce_shop_columns', array(
		'default'           => 3,
		'sanitize_callback' => 'neto_sanitize_shop_columns',
	) );
	$wpc->add_control( 'woocommerce_shop_columns', array(
		'type'    => 'select',
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Product columns', 'neto' ),
		'choices' => neto_get_shop_columns_choices(),
	) );

	$wpc->add_setting( 'woocommerce_shop_posts_per_page', array(
		'default'           => 12,
		'sanitize_callback' => 'absint',
	) );
	$wpc->add_control( 'woocommerce_shop_posts_per_page', array(
		'type'        => 'number',
		'input_attrs' => array(
			'min'  => 1,
			'step' => 1,
		),
		'section'     => 'woocommerce_shop',
		'label'       => esc_html__( 'Products per page', 'neto' ),
	) );

	$wpc->add_setting( 'woocommerce_shop_breadcrumbs', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_shop_breadcrumbs', array(
		'type'    => 'checkbox',
		'section' => 'woocommerce_shop',
		'label'   => esc_html__( 'Show breadcrumbs.', 'neto' ),
	) );

	$wpc->add_setting( 'woocommerce_shop_flipping_animation', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_shop_flipping_animation', array(
		'type'        => 'checkbox',
		'section'     => 'woocommerce_shop',
		'label'       => esc_html__( 'Show second product image on hover.', 'neto' ),
		'description' => esc_html__( "Uses the featured image and the first image in the product's gallery.", 'neto' ),
	) );

	$wpc->add_setting( 'woocommerce_catalog_mode', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_catalog_mode', array(
		'type'        => 'checkbox',
		'section'     => 'woocommerce_shop',
		'label'       => esc_html__( 'Catalog mode.', 'neto' ),
		'description' => esc_html__( 'When catalog mode is enabled, product prices and Add to Cart buttons get hidden. Features that can be individually disabled, such as the Header shopping cart icon, are not affected.', 'neto' ),
	) );



	//
	// WooCommerce Product
	//
	$wpc->add_setting( 'woocommerce_product_reviews', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_product_reviews', array(
		'type'        => 'checkbox',
		'section'     => 'woocommerce_product',
		'label'       => esc_html__( 'Show reviews', 'neto' ),
	) );

	$wpc->add_setting( 'woocommerce_product_upsells', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_product_upsells', array(
		'type'        => 'checkbox',
		'section'     => 'woocommerce_product',
		'label'       => esc_html__( 'Show up-sells.', 'neto' ),
	) );

	$wpc->add_setting( 'woocommerce_product_related', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_product_related', array(
		'type'        => 'checkbox',
		'section'     => 'woocommerce_product',
		'label'       => esc_html__( 'Show related products.', 'neto' ),
	) );

	$wpc->add_setting( 'woocommerce_product_sharing', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'woocommerce_product_sharing', array(
		'type'        => 'checkbox',
		'section'     => 'woocommerce_product',
		'label'       => esc_html__( 'Show social sharing buttons.', 'neto' ),
	) );



	//
	// Footer
	//
	$wpc->add_setting( 'footer_cards', array(
		'default'           => '',
		'sanitize_callback' => 'absint',
	) );
	$wpc->add_control( new WP_Customize_Media_Control( $wpc, 'footer_cards', array(
		'mime_type'   => 'image',
		'section'     => 'footer',
		'label'       => esc_html__( 'Credit Card icons', 'neto' ),
		'description' => esc_html__( 'You need to upload an image containing all the card icons (or similar) that you want displayed.', 'neto' ),
	) ) );

	$wpc->add_setting( 'limit_footer_cards_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'limit_footer_cards_size', array(
		'type'        => 'checkbox',
		'section'     => 'footer',
		'label'       => esc_html__( 'Limit Credit Card icons size (for Retina display)', 'neto' ),
		'description' => esc_html__( 'This option will limit the image size to half its width. You will need to upload your image in 2x the dimension you want to display it in.', 'neto' ),
	) );

	$wpc->add_setting( 'footer_reveal', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'footer_reveal', array(
		'type'        => 'checkbox',
		'section'     => 'footer',
		'label'       => esc_html__( 'Reveal effect.', 'neto' ),
		'description' => esc_html__( 'When enabled, the footer reveals itself progressively instead of following the page.', 'neto' ),
	) );

	$description = wp_kses( sprintf( __( 'Requires the <a href="%s" target="_blank">WP Instagram Widget</a> be assigned to the <strong>Footer - Instagram</strong> widget area.', 'neto' ), 'https://wordpress.org/plugins/wp-instagram-widget/' ), neto_get_allowed_tags( 'guide' ) );
	$wpc->add_setting( 'instagram_auto', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'instagram_auto', array(
		'type'        => 'checkbox',
		'section'     => 'footer',
		'label'       => esc_html__( 'WP Instagram: Slideshow', 'neto' ),
		'description' => $description,
	) );

	$wpc->add_setting( 'instagram_speed', array(
		'default'           => 300,
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'instagram_speed', array(
		'type'        => 'number',
		'section'     => 'footer',
		'label'       => esc_html__( 'WP Instagram: Slideshow Speed', 'neto' ),
		'description' => $description,
	) );



	//
	// Other
	//
	$sample_content_url = apply_filters( 'neto_sample_content_url',
		sprintf( 'https://www.cssigniter.com/sample_content/%s.zip', NETO_NAME ),
		'https://www.cssigniter.com/sample_content/',
		NETO_NAME
	);

	if ( ! empty( $sample_content_url ) && ( ! defined( 'NETO_WHITELABEL' ) || NETO_WHITELABEL == false ) ) {
		$wpc->add_setting( 'sample_content_link', array(
			'default' => '',
		) );
		$wpc->add_control( new Neto_Customize_Static_Text_Control( $wpc, 'sample_content_link', array(
			'section'     => 'other',
			'label'       => esc_html__( 'Resources', 'neto' ),
			'description' => array(
				wp_kses(
					sprintf( __( '<a href="%s" target="_blank">Download the theme\'s sample content</a> to get things moving.', 'neto' ),
						esc_url( $sample_content_url )
					),
					neto_get_allowed_tags( 'guide' )
				),
			),
		) ) );
	}



	//
	// title_tagline Section
	//
	$wpc->add_setting( 'limit_logo_size', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'limit_logo_size', array(
		'type'        => 'checkbox',
		'section'     => 'title_tagline',
		'priority'    => 8,
		'label'       => esc_html__( 'Limit logo size (for Retina display)', 'neto' ),
		'description' => esc_html__( 'This option will limit the image size to half its width. You will need to upload your image in 2x the dimension you want to display it in.', 'neto' ),
	) );

	$wpc->add_setting( 'logo_site_title', array(
		'default'           => 1,
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'logo_site_title', array(
		'type'    => 'checkbox',
		'section' => 'title_tagline',
		'label'   => esc_html__( 'Show site title below the logo.', 'neto' ),
	) );

	$wpc->add_setting( 'logo_tagline', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_checkbox',
	) );
	$wpc->add_control( 'logo_tagline', array(
		'type'    => 'checkbox',
		'section' => 'title_tagline',
		'label'   => esc_html__( 'Show the tagline below the logo.', 'neto' ),
	) );

	$wpc->add_setting( 'logo_padding_top', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'logo_padding_top', array(
		'type'    => 'number',
		'section' => 'title_tagline',
		'label'   => esc_html__( 'Logo top padding', 'neto' ),
	) );

	$wpc->add_setting( 'logo_padding_bottom', array(
		'default'           => '',
		'sanitize_callback' => 'neto_sanitize_intval_or_empty',
	) );
	$wpc->add_control( 'logo_padding_bottom', array(
		'type'    => 'number',
		'section' => 'title_tagline',
		'label'   => esc_html__( 'Logo bottom padding', 'neto' ),
	) );
}

add_action( 'customize_register', 'neto_customize_register_custom_controls', 9 );
/**
 * Registers custom Customizer controls.
 *
 * @param WP_Customize_Manager $wpc Reference to the customizer's manager object.
 */
function neto_customize_register_custom_controls( $wpc ) {
	require get_template_directory() . '/inc/customizer-controls/static-text.php';
}
