<?php
/*
 * Term Meta
 */

add_action( 'product_cat_add_form_fields', 'neto_term_meta_layout_add', 10 );
add_action( 'product_cat_edit_form_fields', 'neto_term_meta_layout_edit', 10, 2 );


if ( ! function_exists( 'neto_term_meta_layout_add' ) ) :
	function neto_term_meta_layout_add( $taxonomy ) {
		?>
		<div class="form-field">
			<label for="neto-term-meta-hero-show"><?php esc_html_e( 'Show hero section', 'neto' ); ?></label>
			<select id="neto-term-meta-hero-show" name="neto-term-meta-hero-show">
				<?php $options = neto_get_hero_show_choices(); ?>
				<?php foreach ( $options as $value => $description ) : ?>
					<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, '' ); ?>><?php echo wp_kses( $description, array() ); ?></option>
				<?php endforeach; ?>
			</select>
		</div>

		<div class="form-field">
			<label for="neto-term-meta-color"><?php esc_html_e( 'Page hero text color', 'neto' ); ?></label>
			<input type="text" id="neto-term-meta-color" name="neto-term-meta-color" class="neto-colorpckr" value="" />
		</div>

		<div class="form-field">
			<label for="neto-term-meta-bg-color"><?php esc_html_e( 'Page hero background color', 'neto' ); ?></label>
			<input type="text" id="neto-term-meta-bg-color" name="neto-term-meta-bg-color" class="neto-colorpckr" value="" />
		</div>

		<div class="form-field term-image-wrap">
			<label for="neto-term-meta-image"><?php esc_html_e( 'Page hero image', 'neto' ); ?></label>
			<div class="ci-upload-preview">
				<div class="upload-preview"></div>
				<input type="hidden" class="ci-uploaded-id" name="neto-term-meta-image" value="" />
				<input id="neto-term-meta-image" type="button" class="button ci-media-button" value="<?php esc_attr_e( 'Select Image', 'neto' ); ?>" />
			</div>
		</div>

		<div class="form-field">
			<label for="neto-term-meta-image-repeat"><?php esc_html_e( 'Page hero image repeat', 'neto' ); ?></label>
			<select id="neto-term-meta-image-repeat" name="neto-term-meta-image-repeat">
				<?php $options = neto_get_image_repeat_choices(); ?>
				<?php foreach ( $options as $value => $description ) : ?>
					<option value="<?php echo esc_attr( $value ); ?>"><?php echo wp_kses( $description, array() ); ?></option>
				<?php endforeach; ?>
			</select>
		</div>

		<div class="form-field">
			<label for="neto-term-meta-image-position-x"><?php esc_html_e( 'Page hero image horizontal position', 'neto' ); ?></label>
			<select id="neto-term-meta-image-position-x" name="neto-term-meta-image-position-x">
				<?php $options = neto_get_image_position_x_choices(); ?>
				<?php foreach ( $options as $value => $description ) : ?>
					<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, 'center' ); ?>><?php echo wp_kses( $description, array() ); ?></option>
				<?php endforeach; ?>
			</select>
		</div>

		<div class="form-field">
			<label for="neto-term-meta-image-position-y"><?php esc_html_e( 'Page hero image vertical position', 'neto' ); ?></label>
			<select id="neto-term-meta-image-position-y" name="neto-term-meta-image-position-y">
				<?php $options = neto_get_image_position_y_choices(); ?>
				<?php foreach ( $options as $value => $description ) : ?>
					<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, 'center' ); ?>><?php echo wp_kses( $description, array() ); ?></option>
				<?php endforeach; ?>
			</select>
		</div>

		<div class="form-field">
			<label for="neto-term-meta-image-attachment"><?php esc_html_e( 'Page hero image attachment', 'neto' ); ?></label>
			<select id="neto-term-meta-image-attachment" name="neto-term-meta-image-attachment">
				<?php $options = neto_get_image_attachment_choices(); ?>
				<?php foreach ( $options as $value => $description ) : ?>
					<option value="<?php echo esc_attr( $value ); ?>"><?php echo wp_kses( $description, array() ); ?></option>
				<?php endforeach; ?>
			</select>
		</div>

		<div class="form-field">
			<label for="neto-term-meta-image-cover">
				<input type="checkbox" id="neto-term-meta-image-cover" name="neto-term-meta-image-cover" value="1"/>
				<?php esc_html_e( 'Scale the image to cover the page hero area.', 'neto' ); ?>
			</label>
		</div>


		<div class="form-field">
			<label for="neto-term-meta-align"><?php esc_html_e( 'Page hero align', 'neto' ); ?></label>
			<select id="neto-term-meta-align" name="neto-term-meta-align">
				<?php $options = neto_get_align_choices(); ?>
				<?php foreach ( $options as $value => $description ) : ?>
					<option value="<?php echo esc_attr( $value ); ?>"><?php echo wp_kses( $description, array() ); ?></option>
				<?php endforeach; ?>
			</select>
		</div>
		<?php
	}
endif;

if ( ! function_exists( 'neto_term_meta_layout_edit' ) ) :
	function neto_term_meta_layout_edit( $term, $taxonomy ) {
		$hero       = neto_sanitize_hero_show( get_term_meta( $term->term_id, 'hero_show', true ) );
		$color      = get_term_meta( $term->term_id, 'header_color', true );
		$bg_color   = get_term_meta( $term->term_id, 'header_bg_color', true );
		$image_id   = get_term_meta( $term->term_id, 'header_image_id', true );
		$repeat     = neto_sanitize_image_repeat( get_term_meta( $term->term_id, 'header_image_repeat', true ) );
		$position_x = neto_sanitize_image_position_x( get_term_meta( $term->term_id, 'header_image_position_x', true ) );
		$position_y = neto_sanitize_image_position_y( get_term_meta( $term->term_id, 'header_image_position_y', true ) );
		$attachment = neto_sanitize_image_attachment( get_term_meta( $term->term_id, 'header_image_attachment', true ) );
		$cover      = get_term_meta( $term->term_id, 'header_image_cover', true );
		$align      = get_term_meta( $term->term_id, 'header_align', true );
		$align      = ! empty( $align ) ? $align : 'center';
		?>

		<tr class="form-field">
			<th scope="row"><label for="neto-term-meta-hero-show"><?php esc_html_e( 'Show hero section', 'neto' ); ?></label></th>
			<td>
				<select id="neto-term-meta-hero-show" name="neto-term-meta-hero-show">
					<?php $options = neto_get_hero_show_choices(); ?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $hero, $value ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</td>
		</tr>

		<tr class="form-field">
			<th scope="row"><label for="neto-term-meta-color"><?php esc_html_e( 'Page hero text color', 'neto' ); ?></label></th>
			<td>
				<input type="text" id="neto-term-meta-color" name="neto-term-meta-color" class="neto-colorpckr" value="<?php echo esc_attr( $color ); ?>" />
			</td>
		</tr>

		<tr class="form-field">
			<th scope="row"><label for="neto-term-meta-bg-color"><?php esc_html_e( 'Page hero background color', 'neto' ); ?></label></th>
			<td>
				<input type="text" id="neto-term-meta-bg-color" name="neto-term-meta-bg-color" class="neto-colorpckr" value="<?php echo esc_attr( $bg_color ); ?>" />
			</td>
		</tr>

		<tr class="form-field term-image-wrap">
			<th scope="row"><label for="neto-term-meta-image"><?php esc_html_e( 'Page hero image', 'neto' ); ?></label></th>
			<td>
				<div class="ci-upload-preview">
					<div class="upload-preview">
						<?php if ( ! empty( $image_id ) ) : ?>
							<?php
								$image_url = neto_get_image_src( $image_id, 'neto_featgal_small_thumb' );
								echo sprintf( '<img src="%s" /><a href="#" class="close media-modal-icon" title="%s"></a>',
									esc_url( $image_url ),
									esc_attr( esc_html__( 'Remove image', 'neto' ) )
								);
							?>
						<?php endif; ?>
					</div>
					<input type="hidden" class="ci-uploaded-id" name="neto-term-meta-image" value="<?php echo esc_attr( $image_id ); ?>" />
					<input id="neto-term-meta-image" type="button" class="button ci-media-button" value="<?php esc_attr_e( 'Select Image', 'neto' ); ?>" />
				</div>
			</td>
		</tr>

		<tr class="form-field">
			<th scope="row"><label for="neto-term-meta-image-repeat"><?php esc_html_e( 'Page hero image repeat', 'neto' ); ?></label></th>
			<td>
				<select id="neto-term-meta-image-repeat" name="neto-term-meta-image-repeat">
					<?php $options = neto_get_image_repeat_choices(); ?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $repeat, $value ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</td>
		</tr>

		<tr class="form-field">
			<th scope="row"><label for="neto-term-meta-image-position-x"><?php esc_html_e( 'Page hero image horizontal position', 'neto' ); ?></label></th>
			<td>
				<select id="neto-term-meta-image-position-x" name="neto-term-meta-image-position-x">
					<?php $options = neto_get_image_position_x_choices(); ?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $position_x, $value ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</td>
		</tr>

		<tr class="form-field">
			<th scope="row"><label for="neto-term-meta-image-position-y"><?php esc_html_e( 'Page hero image vertical position', 'neto' ); ?></label></th>
			<td>
				<select id="neto-term-meta-image-position-y" name="neto-term-meta-image-position-y">
					<?php $options = neto_get_image_position_y_choices(); ?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $position_y, $value ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</td>
		</tr>

		<tr class="form-field">
			<th scope="row"><label for="neto-term-meta-image-attachment"><?php esc_html_e( 'Page hero image attachment', 'neto' ); ?></label></th>
			<td>
				<select id="neto-term-meta-image-attachment" name="neto-term-meta-image-attachment">
					<?php $options = neto_get_image_attachment_choices(); ?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $attachment, $value ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</td>
		</tr>

		<tr class="form-field">
			<th scope="row"><?php esc_html_e( 'Page hero image cover', 'neto' ); ?></th>
			<td>
				<label for="neto-term-meta-image-cover">
					<input type="checkbox" id="neto-term-meta-image-cover" name="neto-term-meta-image-cover" value="1" <?php checked( $cover, 1 ); ?>/>
					<?php esc_html_e( 'Scale the image to cover the page hero area.', 'neto' ); ?>
				</label>
			</td>
		</tr>

		<tr class="form-field">
			<th scope="row"><label for="neto-term-meta-align"><?php esc_html_e( 'Page hero align', 'neto' ); ?></label></th>
			<td>
				<select id="neto-term-meta-align" name="neto-term-meta-align">
					<?php $options = neto_get_align_choices(); ?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $align, $value ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</td>
		</tr>
		<?php
	}
endif;


add_action( 'create_term', 'neto_term_created_edited', 10, 3 );
add_action( 'edit_term', 'neto_term_created_edited', 10, 3 );
if ( ! function_exists( 'neto_term_created_edited' ) ) :
	function neto_term_created_edited( $term_id, $tt_id, $taxonomy ) {
		$taxonomies = array(
			'product_cat',
		);

		if ( in_array( $taxonomy, $taxonomies, true ) ) {
			update_term_meta( $term_id, 'header_align', neto_sanitize_align( $_POST['neto-term-meta-align'] ) );
			update_term_meta( $term_id, 'header_color', neto_sanitize_hex_color( $_POST['neto-term-meta-color'] ) );
			update_term_meta( $term_id, 'header_bg_color', neto_sanitize_hex_color( $_POST['neto-term-meta-bg-color'] ) );
			update_term_meta( $term_id, 'header_image_id', neto_sanitize_intval_or_empty( $_POST['neto-term-meta-image'] ) );
			update_term_meta( $term_id, 'header_image_repeat', neto_sanitize_image_repeat( $_POST['neto-term-meta-image-repeat'] ) );
			update_term_meta( $term_id, 'header_image_position_x', neto_sanitize_image_position_x( $_POST['neto-term-meta-image-position-x'] ) );
			update_term_meta( $term_id, 'header_image_position_y', neto_sanitize_image_position_y( $_POST['neto-term-meta-image-position-y'] ) );
			update_term_meta( $term_id, 'header_image_attachment', neto_sanitize_image_attachment( $_POST['neto-term-meta-image-attachment'] ) );
			update_term_meta( $term_id, 'header_image_cover', neto_sanitize_checkbox_ref( $_POST['neto-term-meta-image-cover'] ) );
			update_term_meta( $term_id, 'hero_show', neto_sanitize_hero_show( $_POST['neto-term-meta-hero-show'] ) );
		}
	}
endif;
