<?php
if ( class_exists( 'Vc_Manager' ) ) {

	add_action( 'wp_enqueue_scripts', 'neto_load_vc_styles', 20 );
	if ( ! function_exists( 'neto_load_vc_styles' ) ) {
		function neto_load_vc_styles() {
			$theme = wp_get_theme();

			wp_enqueue_style( 'neto-visual-composer', get_template_directory_uri() . '/css/visual-composer.css', array(), $theme->get( 'Version' ) );
		}
	}

	add_action( 'vc_before_init', 'neto_vc_set_as_theme' );
	if ( ! function_exists( 'neto_vc_set_as_theme' ) ) :
		function neto_vc_set_as_theme() {
			vc_set_as_theme();
		}
	endif;


	add_action( 'init', 'neto_vc_remove_elements', 20 );
	if ( ! function_exists( 'neto_vc_remove_elements' ) ) :
		function neto_vc_remove_elements() {
			$elements = apply_filters( 'neto_vc_remove_elements', array(
				//'vc_text_separator', // This can't be removed, as vc_separator depends on it. It's both or none.
				'vc_posts_slider',
				'vc_flickr',
				'vc_progress_bar',
				'vc_pie',
				'vc_round_chart',
				'vc_line_chart',
				'vc_wp_search',
				'vc_wp_meta',
				'vc_wp_recentcomments',
				'vc_wp_calendar',
				'vc_wp_pages',
				'vc_wp_tagcloud',
				'vc_wp_custommenu',
				'vc_wp_text',
				'vc_wp_posts',
				'vc_wp_categories',
				'vc_wp_archives',
				'vc_wp_rss',
				'add_to_cart_url',
			) );

			foreach ( $elements as $element ) {
				vc_remove_element( $element );
			}
		}
	endif;

	add_action( 'init', 'neto_vc_remove_element_params', 20 );
	if ( ! function_exists( 'neto_vc_remove_element_params' ) ) :
		function neto_vc_remove_element_params() {
			$elements = apply_filters( 'neto_vc_remove_element_params', array(
				'vc_toggle' => array(
					'style',
					'size',
				),
				'vc_tta_tabs' => array(
					'style',
					'shape',
					'color',
					'no_fill_content_area',
					'spacing',
					'gap',
					//'tab_position', // This can't be removed. Tabs won't work. It's hidden instead: $param['param_holder_class'] = 'sr-only';
					//'autoplay', // This can't be removed. Tabs won't work. It's hidden instead: $param['param_holder_class'] = 'sr-only';
					'alignment',
					'pagination_style',
					'pagination_color',
				),
				'vc_tta_tour' => array(
					'style',
					'shape',
					'color',
					'no_fill_content_area',
					'spacing',
					'gap',
					//'tab_position', // This can't be removed. Tabs won't work. It's hidden instead: $param['param_holder_class'] = 'sr-only';
					//'autoplay', // This can't be removed. Tabs won't work. It's hidden instead: $param['param_holder_class'] = 'sr-only';
					'alignment',
					'pagination_style',
					'pagination_color',
				),
				'vc_tta_accordion' => array(
					'style',
					'shape',
					'color',
					'no_fill',
					'spacing',
					'gap',
					'c_align',
					'autoplay',
				),
				//'vc_basic_grid' => array(
				//	'item',
				//),
				'vc_media_grid' => array(
					'item',
				),
				//'vc_masonry_grid' => array(
				//	'item',
				//),
				'vc_masonry_media_grid' => array(
					'item',
				),
			) );

			foreach ( $elements as $element => $params ) {
				foreach ( $params as $param ) {
					vc_remove_param( $element, $param );
				}
			}
		}
	endif;


	add_action( 'vc_after_init', 'neto_vc_change_element_params', 20 );
	if ( ! function_exists( 'neto_vc_change_element_params' ) ) {
		function neto_vc_change_element_params() {

			$shortcode    = 'vc_btn';
			$param        = WPBMap::getParam( $shortcode, 'style' );
			$param['std'] = 'flat';
			vc_update_shortcode_param( $shortcode, $param );

			$shortcode      = 'vc_btn';
			$param          = WPBMap::getParam( $shortcode, 'color' );
			$param['std']   = 'theme';
			$param['value'] = array_merge( $param['value'], array(
				esc_html__( 'Theme style', 'neto' ) => 'theme',
			) );
			vc_update_shortcode_param( $shortcode, $param );

			$shortcode    = 'vc_btn';
			$param        = WPBMap::getParam( $shortcode, 'shape' );
			$param['std'] = 'square';
			vc_update_shortcode_param( $shortcode, $param );

			// Documentation states that 'class' parameter can be used to echo admin-side classes, but doesn't work.
			// 'param_holder_class' seems to do the trick.
			$shortcode = 'vc_tta_tabs';
			$param     = WPBMap::getParam( $shortcode, 'tab_position' );
			$param['param_holder_class'] = 'sr-only';
			vc_update_shortcode_param( $shortcode, $param );

			$shortcode = 'vc_tta_tabs';
			$param     = WPBMap::getParam( $shortcode, 'autoplay' );
			$param['param_holder_class'] = 'sr-only';
			vc_update_shortcode_param( $shortcode, $param );

			$shortcode = 'vc_tta_tour';
			$param     = WPBMap::getParam( $shortcode, 'tab_position' );
			$param['param_holder_class'] = 'sr-only';
			vc_update_shortcode_param( $shortcode, $param );

			$shortcode = 'vc_tta_tour';
			$param     = WPBMap::getParam( $shortcode, 'autoplay' );
			$param['param_holder_class'] = 'sr-only';
			vc_update_shortcode_param( $shortcode, $param );
		}
	}


	add_action( 'init', 'neto_vc_add_element_params', 20 );
	if ( ! function_exists( 'neto_vc_add_element_params' ) ) :
		function neto_vc_add_element_params() {
			$style = array(
				'type'       => 'dropdown',
				'heading'    => esc_html__( 'Style', 'neto' ),
				'param_name' => 'style',
				'value'      => array(
					esc_html__( 'List', 'neto' )     => 'list',
					esc_html__( 'Carousel', 'neto' ) => 'carousel',
				),
				'std'        => 'list',
			);

			$categories = array(
				'type'       => 'dropdown',
				'heading'    => esc_html__( 'Show categories', 'neto' ),
				'param_name' => 'show_categories',
				'value'      => array(
					esc_html__( 'Yes', 'neto' ) => 'yes',
					esc_html__( 'No', 'neto' )  => 'no',
				),
				'std'        => 'yes',
			);

			$price = array(
				'type'       => 'dropdown',
				'heading'    => esc_html__( 'Show price', 'neto' ),
				'param_name' => 'show_price',
				'value'      => array(
					esc_html__( 'Yes', 'neto' ) => 'yes',
					esc_html__( 'No', 'neto' )  => 'no',
				),
				'std'        => 'yes',
			);

			$elements = apply_filters( 'neto_vc_add_element_params', array(
				'recent_products' => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'neto' ),
						'param_name'  => 'title',
						'value'       => esc_html__( 'Recent Products', 'neto' ),
						'save_always' => true,
					),
					$style,
					$categories,
					$price,
				),
				'featured_products' => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'neto' ),
						'param_name'  => 'title',
						'value'       => esc_html__( 'Featured Products', 'neto' ),
						'save_always' => true,
					),
					$style,
					$categories,
					$price,
				),
				'product' => array(
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Show categories', 'neto' ),
						'param_name'  => 'show_categories',
						'value'       => array(
							esc_html__( 'Yes', 'neto' ) => 'yes',
							esc_html__( 'No', 'neto' )  => 'no',
						),
						'std'         => 'yes',
						'save_always' => true,
					),
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Show price', 'neto' ),
						'param_name'  => 'show_price',
						'value'       => array(
							esc_html__( 'Yes', 'neto' ) => 'yes',
							esc_html__( 'No', 'neto' )  => 'no',
						),
						'std'         => 'yes',
						'save_always' => true,
					),
				),
				'products' => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'neto' ),
						'param_name'  => 'title',
						'value'       => esc_html__( 'Products', 'neto' ),
						'save_always' => true,
					),
					$style,
					$categories,
					$price,
				),
				'product_category' => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'neto' ),
						'param_name'  => 'title',
						'value'       => esc_html__( 'Products', 'neto' ),
						'save_always' => true,
					),
					$style,
					$categories,
					$price,
				),
				'sale_products' => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'neto' ),
						'param_name'  => 'title',
						'value'       => esc_html__( 'On Sale', 'neto' ),
						'save_always' => true,
					),
					$style,
					$categories,
					$price,
				),
				'best_selling_products' => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'neto' ),
						'param_name'  => 'title',
						'value'       => esc_html__( 'Best Sellers', 'neto' ),
						'save_always' => true,
					),
					$style,
					$categories,
					$price,
				),
				'top_rated_products' => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'neto' ),
						'param_name'  => 'title',
						'value'       => esc_html__( 'Top Rated', 'neto' ),
						'save_always' => true,
					),
					$style,
					$categories,
					$price,
				),
				'product_attribute' => array(
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Title', 'neto' ),
						'param_name'  => 'title',
						'value'       => esc_html__( 'Products', 'neto' ),
						'save_always' => true,
					),
					$style,
					$categories,
					$price,
				),
			) );

			foreach ( $elements as $element => $params ) {
				foreach ( $params as $param ) {
					vc_add_param( $element, $param );
				}
			}



			// Hover image for Single Image element.
			$shortcode            = 'vc_single_image';
			$param                = WPBMap::getParam( $shortcode, 'image' );
			$param['param_name']  = 'image2';
			$param['heading']     = esc_html__( 'Image on hover', 'neto' );
			$param['description'] = wp_kses( __( 'Select image from media library. Please note that you must not set a hover image, in order for the <strong>General > On click action > Zoom</strong> option to work.', 'neto' ), neto_get_allowed_tags() );
			$param['group']       = esc_html__( 'Hover', 'neto' );
			$param['dependency']  = array(
				'element' => 'onclick',
				'value'   => array(
					'',
					'img_link_large',
					'link_image',
					'custom_link',
				),
			);

			vc_add_param( $shortcode, $param );

		}
	endif;


	add_action( 'vc_after_init', 'neto_vc_add_elements', 10 );
	if ( ! function_exists( 'neto_vc_add_elements' ) ) :
		function neto_vc_add_elements() {

			$style_tab = esc_html__( 'Style Options', 'neto' );

			vc_map( array(
				'name'            => esc_html__( 'Theme - Banner', 'neto' ),
				'base'            => 'theme_vc_simple_banner',
				'icon'            => get_template_directory_uri() . '/images/theme_vc_simple_banner.png',
				'category'        => esc_html__( 'Content', 'neto' ),
				'description'     => esc_html__( 'Simple banner', 'neto' ),
				'params'          => array(
					array(
						'type'       => 'textfield',
						'param_name' => 'title',
						'heading'    => esc_html__( 'Title', 'neto' ),
					),
					array(
						'type'       => 'textfield',
						'param_name' => 'subtitle',
						'heading'    => esc_html__( 'Subtitle', 'neto' ),
					),
					array(
						'type'       => 'vc_link',
						'param_name' => 'link_url',
						'heading'    => esc_html__( 'Link URL', 'neto' ),
					),
					array(
						'type'       => 'textarea_html',
						'param_name' => 'content',
						'heading'    => esc_html__( 'Content', 'neto' ),
					),
					array(
						'type'        => 'dropdown',
						'heading'     => esc_html__( 'Align text', 'neto' ),
						'param_name'  => 'text_align',
						'value'       => array(
							esc_html__( 'Left', 'neto' ) => 'left',
							esc_html__( 'Center', 'neto' )  => 'center',
							esc_html__( 'Right', 'neto' )  => 'right',
						),
						'std'         => 'left',
						'save_always' => true,
						'group'       => $style_tab,
					),
					array(
						'type'        => 'textfield',
						'param_name'  => 'title_size',
						'heading'     => esc_html__( 'Title size', 'neto' ),
						'description' => esc_html__( 'Font size in pixels', 'neto' ),
						'group'       => $style_tab,
					),
					array(
						'type'        => 'textfield',
						'param_name'  => 'subtitle_size',
						'heading'     => esc_html__( 'Subtitle size', 'neto' ),
						'description' => esc_html__( 'Font size in pixels', 'neto' ),
						'group'       => $style_tab,
					),
					array(
						'type'       => 'colorpicker',
						'param_name' => 'title_color',
						'heading'    => esc_html__( 'Title color', 'neto' ),
						'group'      => $style_tab,
					),
					array(
						'type'       => 'colorpicker',
						'param_name' => 'subtitle_color',
						'heading'    => esc_html__( 'Subtitle color', 'neto' ),
						'group'      => $style_tab,
					),
					array(
						'type'        => 'textfield',
						'heading'     => esc_html__( 'Extra class name', 'neto' ),
						'param_name'  => 'el_class',
						'description' => esc_html__( 'Style particular content element differently - add a class name and refer to it in custom CSS.', 'neto' ),
						'group'       => $style_tab,
					),
					array(
						'type'       => 'css_editor',
						'heading'    => esc_html__( 'CSS box', 'neto' ),
						'param_name' => 'css',
						'group'      => esc_html__( 'Design Options', 'neto' ),
					),
				),
			) );
		}
	endif;


	class WPBakeryShortCode_Theme_VC_Simple_Banner extends WPBakeryShortCode {
		/* Shortcode handler method is protected $this->content( $atts, $content = null ) which can either be
		 * overridden here, or by default it will do a return $this->loadTemplate( $atts, $content );
		 * Note that loadTemplate buffers output, so in the template file we need to echo our shortcode instead of return.
		 */
	}

}
