<?php 
if ( ! class_exists( 'CI_Widget_WC_Product_Attribute' ) ) :
	class CI_Widget_WC_Product_Attribute extends WP_Widget {

		public $ajax_terms  = 'neto_wc_attributes_widget_ajax_get_attribute_terms';

		protected $defaults = array(
			'title'           => '',
			'attribute'       => '',
			'term'            => '',
			'posts_per_page'  => 3,
			'columns'         => 3,
			'orderby'         => 'title',
			'order'           => 'ASC',
			'style'           => 'list',
			'show_categories' => 1,
			'show_price'      => 1,
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Homepage widget. Displays products with a specific attribute.', 'neto' ) );
			$control_ops = array();
			parent::__construct( 'ci-wc-product-attribute', esc_html__( 'Theme - Product Attribute', 'neto' ), $widget_ops, $control_ops );

			if ( is_admin() === true ) {
				add_action( 'wp_ajax_' . $this->ajax_terms, 'CI_Widget_WC_Product_Attribute::_ajax_get_terms' );
			}
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$shortcode = sprintf( '[product_attribute title="%s" attribute="%s" filter="%s" per_page="%s" columns="%s" orderby="%s" order="%s" style="%s" show_categories="%s" show_price="%s"]',
				esc_attr( $title ),
				esc_attr( $instance['attribute'] ),
				esc_attr( $instance['term'] ),
				esc_attr( $instance['posts_per_page'] ),
				esc_attr( $instance['columns'] ),
				esc_attr( $instance['orderby'] ),
				esc_attr( $instance['order'] ),
				esc_attr( $instance['style'] ),
				esc_attr( $instance['show_categories'] ? 'yes' : 'no' ),
				esc_attr( $instance['show_price'] ? 'yes' : 'no' )
			);

			echo $args['before_widget'];

			echo do_shortcode( $shortcode );

			echo $args['after_widget'];

		}

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title'] = sanitize_text_field( $new_instance['title'] );

			// Don't throw a fatal error if WooCommerce isn't enabled.
			if ( function_exists( 'wc_sanitize_taxonomy_name' ) ) {
				$instance['attribute'] = wc_sanitize_taxonomy_name( $new_instance['attribute'] );
				$instance['term']      = wc_sanitize_term_text_based( $new_instance['term'] );
			} else {
				$instance['attribute'] = urldecode( sanitize_title( urldecode( $new_instance['attribute'] ) ) );
				$instance['term']      = trim( wp_unslash( strip_tags( $new_instance['term'] ) ) );
			}

			$instance['posts_per_page']  = intval( $new_instance['posts_per_page'] ) > 0 ? intval( $new_instance['posts_per_page'] ) : 1;
			$instance['columns']         = neto_sanitize_blog_columns( $new_instance['columns'] );
			$instance['orderby']         = in_array( $new_instance['orderby'], array( 'title', 'date', 'modified', 'menu_order title', 'rand' ), true ) ? $new_instance['orderby'] : $this->defaults['orderby'];
			$instance['order']           = in_array( $new_instance['order'], array( 'ASC', 'DESC' ), true ) ? $new_instance['order'] : $this->defaults['order'];
			$instance['style']           = in_array( $new_instance['style'], array( 'list', 'carousel' ), true ) ? $new_instance['style'] : $this->defaults['style'];
			$instance['show_categories'] = neto_sanitize_checkbox_ref( $new_instance['show_categories'] );
			$instance['show_price']      = neto_sanitize_checkbox_ref( $new_instance['show_price'] );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title           = $instance['title'];
			$attribute       = $instance['attribute'];
			$term            = $instance['term'];
			$posts_per_page  = $instance['posts_per_page'];
			$columns         = $instance['columns'];
			$orderby         = $instance['orderby'];
			$order           = $instance['order'];
			$style           = $instance['style'];
			$show_categories = $instance['show_categories'];
			$show_price      = $instance['show_price'];
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat"/></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'posts_per_page' ) ); ?>"><?php esc_html_e( 'Number of products to show:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'posts_per_page' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'posts_per_page' ) ); ?>" type="number" min="1" step="1" value="<?php echo esc_attr( $posts_per_page ); ?>" class="widefat"/></p>

			<p data-ajaxterms="<?php echo esc_attr( $this->ajax_terms ); ?>">
				<label for="<?php echo esc_attr( $this->get_field_id( 'attribute' ) ); ?>"><?php esc_html_e( 'Attribute:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'attribute' ) ); ?>" class="ci-wc-product-attributes-dropdown widefat" name="<?php echo esc_attr( $this->get_field_name( 'attribute' ) ); ?>">
					<?php foreach ( wc_get_attribute_taxonomies() as $attribute_entry ) : ?>
						<option value="<?php echo esc_attr( $attribute_entry->attribute_name ); ?>" <?php selected( $attribute_entry->attribute_name, $attribute ); ?>><?php echo wp_kses( $attribute_entry->attribute_label, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'term' ) ); ?>"><?php esc_html_e( 'Term:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'term' ) ); ?>" class="ci-wc-product-attributes-terms-dropdown widefat" name="<?php echo esc_attr( $this->get_field_name( 'term' ) ); ?>">
					<?php if ( ! empty( $attribute ) ) : ?>
						<?php
							$terms = get_terms( array(
								'taxonomy'   => wc_attribute_taxonomy_name( $attribute ),
								'hide_empty' => false,
							) );
						?>
						<?php foreach ( $terms as $term_entry ) : ?>
							<?php /* translators: %1$s is a product attribute name. %2$d is the number of products with this attribute. */ ?>
							<option value="<?php echo esc_attr( $term_entry->slug ); ?>" <?php selected( $term_entry->slug, $term ); ?>><?php echo wp_kses( sprintf( __( '%1$s (%2$d)', 'neto' ), $term_entry->name, $term_entry->count ), array() ); ?></option>
						<?php endforeach; ?>
					<?php else : ?>
						<option></option>
					<?php endif; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"><?php esc_html_e( 'Columns:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>">
					<?php foreach ( neto_get_blog_columns_choices() as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $columns ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>"><?php esc_html_e( 'Order by:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'orderby' ) ); ?>">
					<?php
						$options = array(
							'title'            => __( 'Title', 'neto' ),
							'date'             => __( 'Date', 'neto' ),
							'modified'         => __( 'Modified Date', 'neto' ),
							'menu_order title' => __( 'Menu Order', 'neto' ),
							'rand'             => __( 'Random', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $orderby ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>"><?php esc_html_e( 'Order:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'order' ) ); ?>">
					<?php
						$options = array(
							'ASC'  => __( 'Ascending', 'neto' ),
							'DESC' => __( 'Descending', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $order ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>"><?php esc_html_e( 'Style:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>">
					<?php
						$options = array(
							'list'     => __( 'List', 'neto' ),
							'carousel' => __( 'Carousel', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $style ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'show_categories' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'show_categories' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'show_categories' ) ); ?>" value="1" <?php checked( $show_categories, 1 ); ?> /><?php esc_html_e( "Show products' categories.", 'neto' ); ?></label></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'show_price' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'show_price' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'show_price' ) ); ?>" value="1" <?php checked( $show_price, 1 ); ?> /><?php esc_html_e( "Show products' price.", 'neto' ); ?></label></p>
			<?php

		}

		static function _ajax_get_terms() {
			$attribute = wc_sanitize_taxonomy_name( $_POST['attribute_name'] );

			if ( ! empty( $attribute ) ) : ?>
				<?php
					$terms = get_terms( array(
						'taxonomy'   => wc_attribute_taxonomy_name( $attribute ),
						'hide_empty' => false,
					) );
				?>
				<?php foreach ( $terms as $term_entry ) : ?>
					<?php /* translators: %1$s is a product attribute name. %2$d is the number of products with this attribute. */ ?>
					<option value="<?php echo esc_attr( $term_entry->slug ); ?>"><?php echo wp_kses( sprintf( __( '%1$s (%2$d)', 'neto' ), $term_entry->name, $term_entry->count ), array() ); ?></option>
				<?php endforeach; ?>
			<?php else : ?>
				<option></option>
			<?php endif;

			wp_die();
		}

	}

	register_widget( 'CI_Widget_WC_Product_Attribute' );

endif;
