<?php 
if ( ! class_exists( 'CI_Widget_WC_Product_Categories' ) ) :
	class CI_Widget_WC_Product_Categories extends WP_Widget {

		protected $defaults = array(
			'title'           => '',
			'categories'      => array(),
			'parent'          => '',
			'posts_per_page'  => '',
			'columns'         => 3,
			'orderby'         => 'name',
			'order'           => 'ASC',
			'style'           => 'list',
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Homepage widget. Displays category thumbnails.', 'neto' ) );
			$control_ops = array();
			parent::__construct( 'ci-wc-product-categories', esc_html__( 'Theme - Product Categories', 'neto' ), $widget_ops, $control_ops );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$ids = $instance['categories'];
			if ( $instance['parent'] >= 1 ) {
				$ids = array();
			}

			$shortcode = sprintf( '[product_categories title="%s" number="%s" orderby="%s" order="%s" columns="%s" parent="%s" ids="%s" style="%s"]',
				esc_attr( $title ),
				esc_attr( $instance['posts_per_page'] ),
				esc_attr( $instance['orderby'] ),
				esc_attr( $instance['order'] ),
				esc_attr( $instance['columns'] ),
				esc_attr( $instance['parent'] >= 1 ? $instance['parent'] : '' ),
				esc_attr( ! empty( $ids ) ? implode( ',', $ids ) : '' ),
				esc_attr( $instance['style'] )
			);

			echo $args['before_widget'];

			echo do_shortcode( $shortcode );

			echo $args['after_widget'];

		}

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title'] = sanitize_text_field( $new_instance['title'] );

			if ( ! empty( $new_instance['categories'] ) && is_array( $new_instance['categories'] ) ) {
				$categories = $new_instance['categories'];
				$categories = array_map( 'intval', $categories );
				$categories = array_filter( $categories );

				$instance['categories'] = $categories;
			} else {
				$instance['categories'] = array();
			}


			$instance['parent']         = neto_sanitize_intval_or_empty( $new_instance['parent'] );
			$instance['posts_per_page'] = neto_sanitize_intval_or_empty( $new_instance['posts_per_page'] );
			$instance['columns']        = neto_sanitize_blog_columns( $new_instance['columns'] );
			$instance['orderby']        = in_array( $new_instance['orderby'], array( 'name', 'term_id', 'description', 'count' ), true ) ? $new_instance['orderby'] : $this->defaults['orderby'];
			$instance['order']          = in_array( $new_instance['order'], array( 'ASC', 'DESC' ), true ) ? $new_instance['order'] : $this->defaults['order'];
			$instance['style']          = in_array( $new_instance['style'], array( 'list', 'carousel' ), true ) ? $new_instance['style'] : $this->defaults['style'];

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title           = $instance['title'];
			$categories      = $instance['categories'];
			$parent          = $instance['parent'];
			$posts_per_page  = $instance['posts_per_page'];
			$columns         = $instance['columns'];
			$orderby         = $instance['orderby'];
			$order           = $instance['order'];
			$style           = $instance['style'];
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat"/></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'categories' ) ); ?>"><?php esc_html_e( 'Product Categories to display:', 'neto' ); ?></label>
			<ul class="exclude-category">
			<?php
				$terms_dd = wp_terms_checklist( 0, array(
					'taxonomy'      => 'product_cat',
					'selected_cats' => $categories,
					'checked_ontop' => false,
					'echo'          => false,
				) );
				echo str_replace( 'tax_input[product_cat][]', $this->get_field_name( 'categories[]' ), $terms_dd );
			?>
			</ul>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'parent' ) ); ?>"><?php esc_html_e( 'or select a parent Product Category to display its children:', 'neto' ); ?></label>
			<?php wp_dropdown_categories( array(
				'taxonomy'          => 'product_cat',
				'show_option_all'   => esc_html__( 'All categories', 'neto' ),
				'show_option_none'  => ' ',
				'option_none_value' => '',
				'show_count'        => 1,
				'echo'              => 1,
				'selected'          => $parent,
				'hierarchical'      => 1,
				'name'              => $this->get_field_name( 'parent' ),
				'id'                => $this->get_field_id( 'parent' ),
				'class'             => 'postform widefat',
			) ); ?>

			<p><?php esc_html_e( 'Please note that if you select a Parent Category, any other selected categories above will be ignored.', 'neto' ); ?></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'posts_per_page' ) ); ?>"><?php esc_html_e( 'Max number of categories to display (empty or 0 for no limit):', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'posts_per_page' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'posts_per_page' ) ); ?>" type="number" min="0" step="1" value="<?php echo esc_attr( $posts_per_page ); ?>" class="widefat"/></p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"><?php esc_html_e( 'Columns:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>">
					<?php foreach ( neto_get_blog_columns_choices() as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $columns ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>"><?php esc_html_e( 'Order by:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'orderby' ) ); ?>">
					<?php
						$options = array(
							'name'        => __( 'Title', 'neto' ),
							'term_id'     => __( 'ID', 'neto' ),
							'description' => __( 'Description', 'neto' ),
							'count'       => __( 'Product count', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $orderby ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>"><?php esc_html_e( 'Order:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'order' ) ); ?>">
					<?php
						$options = array(
							'ASC'  => __( 'Ascending', 'neto' ),
							'DESC' => __( 'Descending', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $order ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>"><?php esc_html_e( 'Style:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>">
					<?php
						$options = array(
							'list'     => __( 'List', 'neto' ),
							'carousel' => __( 'Carousel', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $style ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>
			<?php

		}


	}

	register_widget( 'CI_Widget_WC_Product_Categories' );

endif;
