<?php 
if ( ! class_exists( 'CI_Widget_WC_Product' ) ) :
	class CI_Widget_WC_Product extends WP_Widget {

		protected $defaults = array(
			'title'           => '',
			'product_id'      => '',
			'product_sku'     => '',
			'show_categories' => 1,
			'show_price'      => 1,
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Sidebar widget. Displays a single product.', 'neto' ) );
			$control_ops = array();
			parent::__construct( 'ci-wc-product', esc_html__( 'Theme - Product', 'neto' ), $widget_ops, $control_ops );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$product_id  = $instance['product_id'];
			$product_sku = $instance['product_sku'];

			echo $args['before_widget'];

			if ( $title ) {
				echo $args['before_title'] . $title . $args['after_title'];
			}

			if ( ! empty( $product_id ) ) {
				echo do_shortcode( sprintf( '[product id="%s" show_categories="%s" show_price="%s"]',
					esc_attr( $product_id ),
					esc_attr( $instance['show_categories'] ? 'yes' : 'no' ),
					esc_attr( $instance['show_price'] ? 'yes' : 'no' )
				) );
			} elseif ( ! empty( $product_sku ) ) {
				echo do_shortcode( sprintf( '[product sku="%s" show_categories="%s" show_price="%s"]',
					esc_attr( $product_sku ),
					esc_attr( $instance['show_categories'] ? 'yes' : 'no' ),
					esc_attr( $instance['show_price'] ? 'yes' : 'no' )
				) );
			}

			echo $args['after_widget'];
		}

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title']           = sanitize_text_field( $new_instance['title'] );
			$instance['product_id']      = neto_sanitize_intval_or_empty( $new_instance['product_id'] );
			$instance['product_sku']     = sanitize_text_field( $new_instance['product_sku'] );
			$instance['show_categories'] = neto_sanitize_checkbox_ref( $new_instance['show_categories'] );
			$instance['show_price']      = neto_sanitize_checkbox_ref( $new_instance['show_price'] );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title           = $instance['title'];
			$product_id      = $instance['product_id'];
			$product_sku     = $instance['product_sku'];
			$show_categories = $instance['show_categories'];
			$show_price      = $instance['show_price'];
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat"/></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'product_id' ) ); ?>"><?php esc_html_e( 'Product ID:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'product_id' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'product_id' ) ); ?>" type="text" value="<?php echo esc_attr( $product_id ); ?>" class="widefat"/></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'product_sku' ) ); ?>"><?php esc_html_e( 'or Product SKU:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'product_sku' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'product_sku' ) ); ?>" type="text" value="<?php echo esc_attr( $product_sku ); ?>" class="widefat"/></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'show_categories' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'show_categories' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'show_categories' ) ); ?>" value="1" <?php checked( $show_categories, 1 ); ?> /><?php esc_html_e( "Show products' categories.", 'neto' ); ?></label></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'show_price' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'show_price' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'show_price' ) ); ?>" value="1" <?php checked( $show_price, 1 ); ?> /><?php esc_html_e( "Show products' price.", 'neto' ); ?></label></p>
			<?php

		}


	}

	register_widget( 'CI_Widget_WC_Product' );

endif;
