<?php 
if ( ! class_exists( 'CI_Widget_WC_Products' ) ) :
	class CI_Widget_WC_Products extends WP_Widget {

		protected $defaults = array(
			'title'           => '',
			'ids'             => array(),
			'skus'            => array(),
			'columns'         => 3,
			'orderby'         => 'title',
			'order'           => 'ASC',
			'style'           => 'list',
			'show_categories' => 1,
			'show_price'      => 1,
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Homepage widget. Displays specific products.', 'neto' ) );
			$control_ops = array();
			parent::__construct( 'ci-wc-products', esc_html__( 'Theme - Products', 'neto' ), $widget_ops, $control_ops );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$ids  = $instance['ids'];
			$skus = $instance['skus'];

			if ( empty( $ids ) && empty( $skus ) ) {
				return;
			}

			$id_attr  = ! empty( $ids ) ? ' ids="' . esc_attr( implode( ',', $ids ) ) . '" ' : '';
			$sku_attr = ! empty( $skus ) ? ' skus="' . esc_attr( implode( ',', $skus ) ) . '" ' : '';

			$shortcode = sprintf( '[products %s%s title="%s" columns="%s" orderby="%s" order="%s" style="%s" show_categories="%s" show_price="%s"]',
				$id_attr,
				$sku_attr,
				esc_attr( $title ),
				esc_attr( $instance['columns'] ),
				esc_attr( $instance['orderby'] ),
				esc_attr( $instance['order'] ),
				esc_attr( $instance['style'] ),
				esc_attr( $instance['show_categories'] ? 'yes' : 'no' ),
				esc_attr( $instance['show_price'] ? 'yes' : 'no' )
			);

			echo $args['before_widget'];

			echo do_shortcode( $shortcode );

			echo $args['after_widget'];

		}

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title'] = sanitize_text_field( $new_instance['title'] );

			$instance['ids']  = array_filter( array_map( 'absint', array_map( 'trim', explode( ',', $new_instance['ids'] ) ) ) );
			$instance['skus'] = array_filter( array_map( 'trim', explode( ',', $new_instance['skus'] ) ) );

			$instance['columns']         = neto_sanitize_blog_columns( $new_instance['columns'] );
			$instance['orderby']         = in_array( $new_instance['orderby'], array( 'title', 'date', 'modified', 'menu_order title', 'rand' ), true ) ? $new_instance['orderby'] : $this->defaults['orderby'];
			$instance['order']           = in_array( $new_instance['order'], array( 'ASC', 'DESC' ), true ) ? $new_instance['order'] : $this->defaults['order'];
			$instance['style']           = in_array( $new_instance['style'], array( 'list', 'carousel' ), true ) ? $new_instance['style'] : $this->defaults['style'];
			$instance['show_categories'] = neto_sanitize_checkbox_ref( $new_instance['show_categories'] );
			$instance['show_price']      = neto_sanitize_checkbox_ref( $new_instance['show_price'] );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title           = $instance['title'];
			$ids             = implode( ', ', $instance['ids'] );
			$skus            = implode( ', ', $instance['skus'] );
			$columns         = $instance['columns'];
			$orderby         = $instance['orderby'];
			$order           = $instance['order'];
			$style           = $instance['style'];
			$show_categories = $instance['show_categories'];
			$show_price      = $instance['show_price'];
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat"/></p>

			<p><?php echo wp_kses( __( 'Please note: You must use either only IDs or only SKUs for your products. Using both, will <strong>not</strong> display <strong>any</strong> product. This is a WooCommerce limitation.', 'neto' ), neto_get_allowed_tags( 'guide' ) ); ?></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'ids' ) ); ?>"><?php esc_html_e( 'IDs:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'ids' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'ids' ) ); ?>" type="text" value="<?php echo esc_attr( $ids ); ?>" class="widefat"/></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'skus' ) ); ?>"><?php esc_html_e( 'or Product SKUs:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'skus' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'skus' ) ); ?>" type="text" value="<?php echo esc_attr( $skus ); ?>" class="widefat"/></p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"><?php esc_html_e( 'Columns:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>">
					<?php foreach ( neto_get_blog_columns_choices() as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $columns ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>"><?php esc_html_e( 'Order by:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'orderby' ) ); ?>">
					<?php
						$options = array(
							'title'            => __( 'Title', 'neto' ),
							'date'             => __( 'Date', 'neto' ),
							'modified'         => __( 'Modified Date', 'neto' ),
							'menu_order title' => __( 'Menu Order', 'neto' ),
							'rand'             => __( 'Random', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $orderby ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>"><?php esc_html_e( 'Order:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'order' ) ); ?>">
					<?php
						$options = array(
							'ASC'  => __( 'Ascending', 'neto' ),
							'DESC' => __( 'Descending', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $order ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>"><?php esc_html_e( 'Style:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>">
					<?php
						$options = array(
							'list'     => __( 'List', 'neto' ),
							'carousel' => __( 'Carousel', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $style ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'show_categories' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'show_categories' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'show_categories' ) ); ?>" value="1" <?php checked( $show_categories, 1 ); ?> /><?php esc_html_e( "Show products' categories.", 'neto' ); ?></label></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'show_price' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'show_price' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'show_price' ) ); ?>" value="1" <?php checked( $show_price, 1 ); ?> /><?php esc_html_e( "Show products' price.", 'neto' ); ?></label></p>
			<?php

		}

	}

	register_widget( 'CI_Widget_WC_Products' );

endif;
