<?php 
if ( ! class_exists( 'CI_Widget_WC_Recent_Products' ) ) :
	class CI_Widget_WC_Recent_Products extends WP_Widget {

		protected $defaults = array(
			'title'           => '',
			'categories'      => array(),
			'posts_per_page'  => 3,
			'columns'         => 3,
			'orderby'         => 'title',
			'order'           => 'ASC',
			'operator'        => 'IN',
			'style'           => 'list',
			'show_categories' => 1,
			'show_price'      => 1,
		);

		function __construct() {
			$widget_ops  = array( 'description' => esc_html__( 'Homepage widget. Displays recent products, optionally from one or more selected categories.', 'neto' ) );
			$control_ops = array();
			parent::__construct( 'ci-wc-recent-products', esc_html__( 'Theme - Recent Products', 'neto' ), $widget_ops, $control_ops );
		}

		function widget( $args, $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );

			$cat_slugs = array();
			foreach ( $instance['categories'] as $cat_id ) {
				$category = get_term( $cat_id, 'product_cat' );
				if ( ! is_null( $category ) && ! is_wp_error( $category ) ) {
					$cat_slugs[] = $category->slug;
				}
			}
			$cat_slugs = implode( ' ', $cat_slugs );

			$shortcode = sprintf( '[recent_products title="%s" per_page="%s" columns="%s" orderby="%s" order="%s" category="%s" operator="%s" style="%s" show_categories="%s" show_price="%s"]',
				esc_attr( $title ),
				esc_attr( $instance['posts_per_page'] ),
				esc_attr( $instance['columns'] ),
				esc_attr( $instance['orderby'] ),
				esc_attr( $instance['order'] ),
				esc_attr( $cat_slugs ),
				esc_attr( $instance['operator'] ),
				esc_attr( $instance['style'] ),
				esc_attr( $instance['show_categories'] ? 'yes' : 'no' ),
				esc_attr( $instance['show_price'] ? 'yes' : 'no' )
			);

			echo $args['before_widget'];

			echo do_shortcode( $shortcode );

			echo $args['after_widget'];

		}

		function update( $new_instance, $old_instance ) {
			$instance = $old_instance;

			$instance['title'] = sanitize_text_field( $new_instance['title'] );

			if ( ! empty( $new_instance['categories'] ) && is_array( $new_instance['categories'] ) ) {
				$categories = $new_instance['categories'];
				$categories = array_map( 'intval', $categories );
				$categories = array_filter( $categories );

				$instance['categories'] = $categories;
			} else {
				$instance['categories'] = array();
			}


			$instance['posts_per_page']  = intval( $new_instance['posts_per_page'] ) > 0 ? intval( $new_instance['posts_per_page'] ) : 1;
			$instance['columns']         = neto_sanitize_blog_columns( $new_instance['columns'] );
			$instance['orderby']         = in_array( $new_instance['orderby'], array( 'title', 'date', 'modified', 'menu_order title', 'rand' ), true ) ? $new_instance['orderby'] : $this->defaults['orderby'];
			$instance['order']           = in_array( $new_instance['order'], array( 'ASC', 'DESC' ), true ) ? $new_instance['order'] : $this->defaults['order'];
			$instance['operator']        = in_array( $new_instance['operator'], array( 'IN', 'NOT IN', 'AND' ), true ) ? $new_instance['operator'] : $this->defaults['operator'];
			$instance['style']           = in_array( $new_instance['style'], array( 'list', 'carousel' ), true ) ? $new_instance['style'] : $this->defaults['style'];
			$instance['show_categories'] = neto_sanitize_checkbox_ref( $new_instance['show_categories'] );
			$instance['show_price']      = neto_sanitize_checkbox_ref( $new_instance['show_price'] );

			return $instance;
		}

		function form( $instance ) {
			$instance = wp_parse_args( (array) $instance, $this->defaults );

			$title           = $instance['title'];
			$categories      = $instance['categories'];
			$posts_per_page  = $instance['posts_per_page'];
			$columns         = $instance['columns'];
			$orderby         = $instance['orderby'];
			$order           = $instance['order'];
			$operator        = $instance['operator'];
			$style           = $instance['style'];
			$show_categories = $instance['show_categories'];
			$show_price      = $instance['show_price'];
			?>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" class="widefat"/></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'posts_per_page' ) ); ?>"><?php esc_html_e( 'Number of products to show:', 'neto' ); ?></label><input id="<?php echo esc_attr( $this->get_field_id( 'posts_per_page' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'posts_per_page' ) ); ?>" type="number" min="1" step="1" value="<?php echo esc_attr( $posts_per_page ); ?>" class="widefat"/></p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'categories' ) ); ?>"><?php esc_html_e( 'Product Categories:', 'neto' ); ?></label>
			<ul class="exclude-category">
			<?php
				$terms_dd = wp_terms_checklist( 0, array(
					'taxonomy'      => 'product_cat',
					'selected_cats' => $categories,
					'checked_ontop' => false,
					'echo'          => false,
				) );
				echo str_replace( 'tax_input[product_cat][]', $this->get_field_name( 'categories[]' ), $terms_dd );
			?>
			</ul>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"><?php esc_html_e( 'Columns:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>">
					<?php foreach ( neto_get_blog_columns_choices() as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $columns ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>"><?php esc_html_e( 'Order by:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'orderby' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'orderby' ) ); ?>">
					<?php
						$options = array(
							'title'            => __( 'Title', 'neto' ),
							'date'             => __( 'Date', 'neto' ),
							'modified'         => __( 'Modified Date', 'neto' ),
							'menu_order title' => __( 'Menu Order', 'neto' ),
							'rand'             => __( 'Random', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $orderby ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>"><?php esc_html_e( 'Order:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'order' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'order' ) ); ?>">
					<?php
						$options = array(
							'ASC'  => __( 'Ascending', 'neto' ),
							'DESC' => __( 'Descending', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $order ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'operator' ) ); ?>"><?php esc_html_e( 'Show products:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'operator' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'operator' ) ); ?>">
					<?php
						$options = array(
							'IN'     => __( 'In any of the selected categories', 'neto' ),
							'NOT IN' => __( 'Not in the selected categories', 'neto' ),
							'AND'    => __( 'In all of the selected categories', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $operator ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p>
				<label for="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>"><?php esc_html_e( 'Style:', 'neto' ); ?></label>
				<select id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>" class="widefat" name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>">
					<?php
						$options = array(
							'list'     => __( 'List', 'neto' ),
							'carousel' => __( 'Carousel', 'neto' ),
						);
					?>
					<?php foreach ( $options as $value => $description ) : ?>
						<option value="<?php echo esc_attr( $value ); ?>" <?php selected( $value, $style ); ?>><?php echo wp_kses( $description, array() ); ?></option>
					<?php endforeach; ?>
				</select>
			</p>

			<p><label for="<?php echo esc_attr( $this->get_field_id( 'show_categories' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'show_categories' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'show_categories' ) ); ?>" value="1" <?php checked( $show_categories, 1 ); ?> /><?php esc_html_e( "Show products' categories.", 'neto' ); ?></label></p>
			<p><label for="<?php echo esc_attr( $this->get_field_id( 'show_price' ) ); ?>"><input type="checkbox" name="<?php echo esc_attr( $this->get_field_name( 'show_price' ) ); ?>" id="<?php echo esc_attr( $this->get_field_id( 'show_price' ) ); ?>" value="1" <?php checked( $show_price, 1 ); ?> /><?php esc_html_e( "Show products' price.", 'neto' ); ?></label></p>
			<?php

		}


	}

	register_widget( 'CI_Widget_WC_Recent_Products' );

endif;
