<?php
add_action( 'after_setup_theme', 'neto_woocommerce_setup' );
if ( ! function_exists( 'neto_woocommerce_setup' ) ) :
	function neto_woocommerce_setup() {
		// Let WooCommerce know that we support it.
		add_theme_support( 'woocommerce', array(
			'thumbnail_image_width'         => 540,
			'single_image_width'            => 540,
			'gallery_thumbnail_image_width' => 100,
		) );

		if ( class_exists( 'WooCommerce' ) ) {

			// Disable WooCommerce's prettyPhoto
			add_action( 'wp_enqueue_scripts', 'neto_disable_prettyphoto' );
			if ( ! function_exists( 'neto_disable_prettyphoto' ) ) :
				function neto_disable_prettyphoto() {
					wp_dequeue_script( 'prettyPhoto' );
					wp_dequeue_script( 'prettyPhoto-init' );
					wp_dequeue_style( 'woocommerce_prettyPhoto_css' );
				}
			endif;

			// Skip the default woocommerce styling and use our boilerplate.
			add_filter( 'woocommerce_enqueue_styles', 'neto_woocommerce_deregister_styles' );
			if ( ! function_exists( 'neto_woocommerce_deregister_styles' ) ) :
				function neto_woocommerce_deregister_styles() {
					wp_deregister_style( 'woocommerce-general' );
				}
			endif;


			// It looks like actions 'after_setup_theme' and 'init' are too early in order for get_theme_mod() values
			// to be previewed from the customizer.
			add_action( 'wp', 'neto_woocommerce_remove_breadcrumbs' );
			if ( ! function_exists( 'neto_woocommerce_remove_breadcrumbs' ) ) :
				function neto_woocommerce_remove_breadcrumbs() {
					// Remove breadcrumbs.
					if ( ! get_theme_mod( 'woocommerce_shop_breadcrumbs', 1 ) ) {
						remove_action( 'woocommerce_before_main_content', 'woocommerce_breadcrumb', 20 );
					}
				}
			endif;

			add_filter( 'woocommerce_breadcrumb_defaults', 'neto_woocommerce_breadcrumb_defaults' );
			if ( ! function_exists( 'neto_woocommerce_breadcrumb_defaults' ) ) :
				function neto_woocommerce_breadcrumb_defaults( $defaults ) {
					if ( is_product() ) {
						$defaults['wrap_before'] = '<div class="container"><div class="row"><div class="col-xs-12">' . $defaults['wrap_before'];
						$defaults['wrap_after']  = $defaults['wrap_after'] . '</div></div></div>';
					}

					return $defaults;
				}
			endif;

			add_filter( 'woocommerce_breadcrumb_defaults', 'neto_change_breadcrumb_delimiter' );
			if ( ! function_exists( 'neto_change_breadcrumb_delimiter' ) ) {
				function neto_change_breadcrumb_delimiter( $defaults ) {
					$defaults['delimiter'] = '<span>/</span>';
					return $defaults;
				}
			}

			if ( ! function_exists( 'woocommerce_taxonomy_archive_description' ) ) {
				function woocommerce_taxonomy_archive_description() {
					if ( is_tax( array( 'product_cat', 'product_tag' ) ) && 0 === absint( get_query_var( 'paged' ) ) ) {
						$description = wc_format_content( term_description() );
						if ( $description ) {
							echo '<div class="page-hero-subtitle">' . $description . '</div>';
						}
					}
				}
			}
			if ( ! function_exists( 'woocommerce_product_archive_description' ) ) {
				function woocommerce_product_archive_description() {
					if ( is_post_type_archive( 'product' ) && 0 === absint( get_query_var( 'paged' ) ) ) {
						$shop_page   = get_post( wc_get_page_id( 'shop' ) );
						if ( $shop_page ) {
							$description = wc_format_content( $shop_page->post_content );
							if ( $description ) {
								echo '<div class="page-hero-subtitle">' . $description . '</div>';
							}
						}
					}
				}
			}


			// Remove result count, e.g. "Showing 1–10 of 22 results", added manually
			remove_action( 'woocommerce_before_shop_loop', 'woocommerce_result_count', 20 );
			add_action( 'woocommerce_before_shop_loop', 'neto_woocommerce_shop_actions', 20 );
			if ( ! function_exists( 'neto_woocommerce_shop_actions' ) ) :
				function neto_woocommerce_shop_actions() {
					?>
					<div class="actions">

						<?php if ( 'full' === get_theme_mod( 'woocommerce_shop_layout', 'left' ) && is_active_sidebar( 'eshop' ) ) : ?>
							<a href="#"	class="shop-filter-toggle">
								<i class="fa fa-navicon"></i> <?php esc_html_e( 'Filters', 'neto' ); ?>
							</a>
						<?php endif; ?>

						<?php woocommerce_result_count(); ?>

						<?php
							$first  = absint( apply_filters( 'neto_products_view_first', 25 ) );
							$second = absint( apply_filters( 'neto_products_view_second', 50 ) );
						?>
						<div class="product-number">
							<span><?php esc_html_e( 'View:', 'neto' ); ?></span>
							<a href="<?php echo esc_url( add_query_arg( 'view', $first, get_permalink( wc_get_page_id( 'shop' ) ) ) ); ?>"><?php echo esc_html( $first ); ?></a>
							<a href="<?php echo esc_url( add_query_arg( 'view', $second, get_permalink( wc_get_page_id( 'shop' ) ) ) ); ?>"><?php echo esc_html( $second ); ?></a>
							<?php if ( apply_filters( 'neto_products_view_all', true ) ) : ?>
								<a href="<?php echo esc_url( add_query_arg( 'view', 'all', get_permalink( wc_get_page_id( 'shop' ) ) ) ); ?>"><?php esc_html_e( 'All', 'neto' ); ?></a>
							<?php endif; ?>
						</div>

					</div><!-- .actions -->
					<?php
				}
			endif;

			add_filter( 'loop_shop_per_page', 'neto_woocommerce_loop_shop_per_page_view' );
			if ( ! function_exists( 'neto_woocommerce_loop_shop_per_page_view' ) ) :
				function neto_woocommerce_loop_shop_per_page_view( $posts_per_page ) {

					$custom = get_theme_mod( 'woocommerce_shop_posts_per_page', 12 );
					if ( ! empty( $custom ) ) {
						$posts_per_page = $custom;
					}

					if ( empty( $_GET['view'] ) ) {
						return $posts_per_page;
					}

					if ( 'all' === $_GET['view'] ) {
						$view = - 1;
					} else {
						$view = absint( $_GET['view'] );
					}

					$first  = absint( apply_filters( 'neto_products_view_first', 25 ) );
					$second = absint( apply_filters( 'neto_products_view_second', 50 ) );

					$valid_values = array( $posts_per_page );

					if ( $first ) {
						$valid_values[] = $first;
					}

					if ( $second ) {
						$valid_values[] = $second;
					}

					if ( apply_filters( 'neto_products_view_all', true ) ) {
						$valid_values[] = -1;
					}

					if ( in_array( $view, $valid_values, true ) ) {
						return $view;
					}

					return $posts_per_page;
				}
			endif;



			// Remove the link that surrounds the product and category in shop loop.
			remove_action( 'woocommerce_before_shop_loop_item', 'woocommerce_template_loop_product_link_open', 10 );
			remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_product_link_close', 5 );


			// Override the product thumbnail hooked function, as we want to change its output.
			if ( ! function_exists( 'woocommerce_template_loop_product_thumbnail' ) ) :
				function woocommerce_template_loop_product_thumbnail() {
					?>
					<div class="item-thumb">
						<a href="<?php the_permalink(); ?>">
							<?php echo woocommerce_get_product_thumbnail(); ?>
							<?php
								global $product;
								// Get the product attachments so that we can bring the second attached image
								$attachment_ids = $product->get_gallery_image_ids();

								if ( get_theme_mod( 'woocommerce_shop_flipping_animation', 1 ) ) {
									foreach ( $attachment_ids as $attachment ) {
										// Make sure we don't get the featured image again in case someone also puts it in the product gallery
										if ( get_post_thumbnail_id( get_the_ID() ) !== $attachment ) {
											echo wp_get_attachment_image( $attachment, 'shop_catalog', false );
											break;
										}
									}
								}
							?>
						</a>
					</div>
				<?php
				}
			endif;


			// Show the product categories in the loop.
			add_action( 'woocommerce_shop_loop_item_title', 'neto_woocommerce_loop_item_category', 5 );
			if ( ! function_exists( 'neto_woocommerce_loop_item_category' ) ) :
				function neto_woocommerce_loop_item_category() {
					global $product;
					echo wc_get_product_category_list( $product->get_id(), ', ', '<p class="item-eyebrow">', '</p>' );
				}
			endif;


			if ( ! function_exists( 'woocommerce_template_loop_product_title' ) ) {
				function woocommerce_template_loop_product_title() {
					echo sprintf( '<p class="item-title"><a href="%1$s">%2$s</a></p>',
						esc_url( get_the_permalink() ),
						get_the_title()
					);
				}
			}

			if ( ! function_exists( 'woocommerce_template_loop_category_title' ) ) {
				function woocommerce_template_loop_category_title( $category ) {
					?>
					<p class="item-title">
						<a href="<?php echo esc_url( get_term_link( $category, 'product_cat' ) ); ?>">
							<?php
								echo $category->name;

								if ( $category->count > 0 ) {
									echo apply_filters( 'woocommerce_subcategory_count_html', ' <span class="count">(' . $category->count . ')</span>', $category );
								}
							?>
						</a>
					</p>
					<?php
				}
			}

			// We don't need the Rating and Add to Cart button in the listing.
			remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_rating', 5 );
			remove_action( 'woocommerce_after_shop_loop_item', 'woocommerce_template_loop_add_to_cart', 10 );


			// Remove the link that surrounds the category in shop loop.
			remove_action( 'woocommerce_before_subcategory', 'woocommerce_template_loop_category_link_open', 10 );
			remove_action( 'woocommerce_after_subcategory', 'woocommerce_template_loop_category_link_close', 10 );


			// Moved notices on top of the columns of the shop page (and use our own function).
			remove_action( 'woocommerce_before_shop_loop', 'wc_print_notices', 10 );
			add_action( 'woocommerce_before_main_content', 'neto_wc_print_notices', 20 );
			// Remove notices in single product. We'll call it manually using our own function.
			remove_action( 'woocommerce_before_single_product', 'wc_print_notices', 10 );
			add_action( 'woocommerce_before_single_product', 'neto_wc_print_notices', 10 );

			if ( ! function_exists( 'neto_wc_print_notices' ) ) :
				function neto_wc_print_notices() {
					if ( wc_notice_count() > 0 ) {
						?>
						<div class="container">
							<div class="row">
								<div class="col-xs-12">
									<?php wc_print_notices(); ?>
								</div>
							</div>
						</div>
						<?php
					}
				}
			endif;

			// Change number of columns in product loop
			add_filter( 'loop_shop_columns', 'neto_woocommerce_loop_show_columns' );
			if ( ! function_exists( 'neto_woocommerce_loop_show_columns' ) ) :
				function neto_woocommerce_loop_show_columns() {
					return intval( get_theme_mod( 'woocommerce_shop_columns', 3 ) );
				}
			endif;

			// Change number of columns and counts, in related products and up-sells.
			add_filter( 'neto_woocommerce_related_products_count', 'neto_woocommerce_related_columns' );
			add_filter( 'woocommerce_related_products_columns', 'neto_woocommerce_related_columns' );
			add_filter( 'neto_woocommerce_up_sells_products_count', 'neto_woocommerce_related_columns' );
			add_filter( 'woocommerce_up_sells_columns', 'neto_woocommerce_related_columns' );
			if ( ! function_exists( 'neto_woocommerce_related_columns' ) ) :
				function neto_woocommerce_related_columns() {
					return 4;
				}
			endif;

			// Change posts_per_page on upsell products
			add_filter( 'woocommerce_upsells_total', 'ci_woocommerce_upsells_total' );
			if ( !function_exists( 'ci_woocommerce_upsells_total' ) ):
			function ci_woocommerce_upsells_total( $limit ) {
				$limit =  4;
				return $limit;
			}
			endif;

			add_filter( 'woocommerce_cross_sells_total', 'neto_woocommerce_cross_sells_columns' );
			add_filter( 'woocommerce_cross_sells_columns', 'neto_woocommerce_cross_sells_columns' );
			if ( ! function_exists( 'neto_woocommerce_cross_sells_columns' ) ) :
				function neto_woocommerce_cross_sells_columns() {
					return 3;
				}
			endif;


			// Move the sale flash along with the product image.
			remove_action( 'woocommerce_before_single_product_summary', 'woocommerce_show_product_sale_flash', 10 );
			add_action( 'woocommerce_product_thumbnails', 'woocommerce_show_product_sale_flash', 10 );

			// Move rating after the price
			remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 10 );
			add_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_rating', 15 );


			add_filter( 'woocommerce_product_tabs', 'neto_woocommerce_remove_review_tab', 20 );
			if ( ! function_exists( 'neto_woocommerce_remove_review_tab' ) ) :
				function neto_woocommerce_remove_review_tab( $tabs ) {
					if ( ! get_theme_mod( 'woocommerce_product_reviews', 1 ) ) {
						unset( $tabs['reviews'] );
					}
					return $tabs;
				}
			endif;


			// It looks like actions 'after_setup_theme' and 'init' are too early in order for get_theme_mod() values
			// to be previewed from the customizer.
			add_action( 'wp', 'neto_woocommerce_maybe_remove_related_upsells' );
			if ( ! function_exists( 'neto_woocommerce_maybe_remove_related_upsells' ) ) :
				function neto_woocommerce_maybe_remove_related_upsells() {
					if ( ! get_theme_mod( 'woocommerce_product_upsells', 1 ) ) {
						remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_upsell_display', 15 );
					}

					if ( ! get_theme_mod( 'woocommerce_product_related', 1 ) ) {
						remove_action( 'woocommerce_after_single_product_summary', 'woocommerce_output_related_products', 20 );
					}
				}
			endif;


			add_action( 'woocommerce_share', 'neto_woocommerce_share' );
			if ( ! function_exists( 'neto_woocommerce_share' ) ) :
				function neto_woocommerce_share() {
					if ( get_theme_mod( 'woocommerce_product_sharing', 1 ) ) {
						get_template_part( 'part-social-sharing' );
					}
				}
			endif;


			// Make some WooCommerce pages get the fullwidth template
			add_filter( 'template_include', 'neto_woocommerce_cart_fullwidth' );
			if ( ! function_exists( 'neto_woocommerce_cart_fullwidth' ) ) :
				function neto_woocommerce_cart_fullwidth( $template ) {
					$filename = 'template-fullwidth.php';
					$located  = '';
					if ( file_exists( get_stylesheet_directory() . '/' . $filename ) ) {
						$located = get_stylesheet_directory() . '/' . $filename;
					} elseif ( file_exists( get_template_directory() . '/' . $filename ) ) {
						$located = get_template_directory() . '/' . $filename;
					} else {
						$located = '';
					}

					if ( ! empty( $located ) && ( is_cart() || is_checkout() || is_account_page() ) ) {
						return $located;
					}

					return $template;
				}
			endif;


			// De-register the widgets that WooCommerce provides, and register ours.
			// We can't just remove_action() as the original classes are included from $woocommerce->register_widgets()
			// so the original classes wil be unavailable, and we need them.
			add_action( 'widgets_init', 'neto_woocommerce_register_widgets' );
			if ( ! function_exists( 'neto_woocommerce_register_widgets' ) ) :
				function neto_woocommerce_register_widgets() {
					// Register the widgets that extend the original WooCommerce widgets.

					if ( class_exists( 'WC_Widget_Recent_Reviews' ) ) {
						require get_template_directory() . '/inc/widgets/class-wc-widget-recent-reviews.php';
						unregister_widget( 'WC_Widget_Recent_Reviews' );
						register_widget( 'Neto_WC_Widget_Recent_Reviews' );
					}
				}
			endif;


			add_action( 'woocommerce_before_customer_login_form', 'neto_woocommerce_before_customer_login_form' );
			if ( ! function_exists( 'neto_woocommerce_before_customer_login_form' ) ) :
				function neto_woocommerce_before_customer_login_form() {
					$registration_class = get_option( 'woocommerce_enable_myaccount_registration' ) === 'yes' ? 'with-register' : '';
					?>
					<div class="wc-form-login <?php echo esc_attr( $registration_class ); ?>">
						<style>.entry-title { display: none; }</style>
					<?php
				}
			endif;

			add_action( 'woocommerce_after_customer_login_form', 'neto_woocommerce_after_customer_login_form' );
			if ( ! function_exists( 'neto_woocommerce_after_customer_login_form' ) ) :
				function neto_woocommerce_after_customer_login_form() {
					?></div><?php
				}
			endif;

			// It looks like actions 'after_setup_theme' and 'init' are too early in order for get_theme_mod() values
			// to be previewed from the customizer.
			add_action( 'wp', 'neto_woocommerce_handle_catalog_mode' );
			if ( ! function_exists( 'neto_woocommerce_handle_catalog_mode' ) ) :
				function neto_woocommerce_handle_catalog_mode() {
					if ( ! get_theme_mod( 'woocommerce_catalog_mode' ) ) {
						return;
					}

					// Anything that can be removed by unhooking, is here.
					// There are a few instances that get_theme_mod( 'woocommerce_catalog_mode' ) needed to be checked
					// in templates, such as in content-widget-product.php and Neto_WC_Widget_Recent_Reviews widget.
					remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_price', 10 );
					remove_action( 'woocommerce_single_product_summary', 'woocommerce_template_single_add_to_cart', 30 );

					remove_action( 'woocommerce_after_shop_loop_item_title', 'woocommerce_template_loop_price', 10 );
				}
			endif;

			add_filter( 'woocommerce_single_product_image_thumbnail_html', 'neto_woocommerce_single_product_image_thumbnail_html', 10, 2 );
			function neto_woocommerce_single_product_image_thumbnail_html( $html, $attachment_id ) {
				$html = str_replace( '<a ', '<a data-rel="prettyPhoto[product-gallery]" ', $html );

				return $html;
			}
		} //class_exists() WooCommerce.
	}
endif;
