jQuery(function( $ ) {
	'use strict';

	var $body = $('body');

	/* -----------------------------------------
	Responsive Menus Init with mmenu
	----------------------------------------- */
	var $navs      = $( '.nav-bar' );
	var $mainNav   = $( '.navigation-mobile' );
	var $mobileNav = $( '#mobilemenu' );

	$mainNav.clone().removeAttr( 'id' ).removeClass().appendTo( $mobileNav );
	$mobileNav.find( 'li' ).removeAttr( 'id' );

	$mobileNav.mmenu({
		offCanvas: {
			position: 'top',
			zposition: 'front'
		},
		"autoHeight": true,
		"navbars": [
			{
				"position": "top",
				"content": [
					"prev",
					"title",
					"close"
				]
			}
		]
	});

	/* -----------------------------------------
	Header search trigger
	----------------------------------------- */
	var $searchTrigger = $('.head-search-trigger');
	var $searchDismiss = $('.head-search-dismiss');
	var $headSearch    = $('.mast-head-search');

	function dismissHeadSearch(e) {
		if (e) {
			e.preventDefault();
		}

		$headSearch.removeClass('head-search-open');
		$body.focus();
	}

	function displayHeadSearch(e) {
		if (e) {
			e.preventDefault();
		}

		$headSearch
			.addClass('head-search-open')
			.find('input')
			.focus();
	}

	function isHeadSearchVisible() {
		return $headSearch.hasClass('head-search-open')
	}

	$searchTrigger.on('click', displayHeadSearch);
	$searchDismiss.on('click', dismissHeadSearch);

	/* -----------------------------------------
	Shop filters toggle
	----------------------------------------- */
	var $filtersWrap    = $('.sidebar-drawer');
	var $filtersToggle  = $('.shop-filter-toggle');
	var $filtersDismiss = $('.sidebar-dismiss');

	function isFiltersVisible() {
		return $filtersWrap.hasClass('sidebar-drawer-visible');
	}

	function dismissFilters(e) {
		if (e) {
			e.preventDefault();
		}
		$filtersWrap.removeClass('sidebar-drawer-visible')
	}

	function displayFilters(e) {
		if (e) {
			e.preventDefault();
		}
		$filtersWrap.addClass('sidebar-drawer-visible');
	}

	$filtersToggle.on('click', displayFilters);
	$filtersDismiss.on('click', dismissFilters);

	/* Event propagations */
	$(document).on('keydown', function (e) {
		e = e || window.e;
		if (e.keyCode === 27 && (isHeadSearchVisible() || isFiltersVisible())) {
			dismissHeadSearch(e);
			dismissFilters(e)
		}
	});

	$body
		.on('click', function (e) {
			if (isHeadSearchVisible()) {
				dismissHeadSearch();
			}

			if (isFiltersVisible()) {
				dismissFilters()
			}
		})
		.find('.mast-head-search, .head-search-trigger, .shop-filter-toggle, .sidebar-drawer')
		.on('click', function (e) {
			e.stopPropagation();
		});

	/* -----------------------------------------
	Header Search Cart
	----------------------------------------- */
	var headCart     = $('.head-cart');
	var headCartWrap = $('.head-cart-wrap');

	headCart
		.on('mouseenter', function (e) {
			$(this).addClass('is-visible');
			headCartWrap.stop().fadeIn(200);
		})
		.on('mouseleave', function (e) {
			$(this).removeClass('is-visible');
			headCartWrap.stop().fadeOut(200);
		});

	/* -----------------------------------------
	Main Navigation Init
	----------------------------------------- */
	$navs.superfish({
		delay: 300,
		animation: { opacity: 'show', height: 'show' },
		speed: 'fast',
		dropShadows: false
	});

	/* -----------------------------------------
	Sticky Header
	----------------------------------------- */
	var $siteBar = $('.mast-head-stick');

	if ( $siteBar.length ) {
		$siteBar.stick_in_parent({
			bottoming: false,
			parent: '#page'
		});
	}

	/* -----------------------------------------
	Responsive Videos with fitVids
	----------------------------------------- */
	$body.fitVids();

	/* -----------------------------------------
	Lightboxes
	----------------------------------------- */

	$( '.ci-lightbox, a[data-lightbox^="gal"]' ).magnificPopup({
		type: 'image',
		mainClass: 'mfp-with-zoom',
		gallery: {
			enabled: true
		},
		zoom: {
			enabled: true
		}
	} );

	// WooCommerce specific functionality
	// addressing variable products with different thumbnails
	$('.zoom, .woocommerce-product-gallery__image a').magnificPopup({
		type: 'image',
		mainClass: 'mfp-with-zoom',
		gallery: {
			enabled: true
		},
		callbacks: {
			beforeOpen: function() {
				var instance = $.magnificPopup.instance;
				instance.items = $('.zoom, .woocommerce-product-gallery__image a').map(function () {
					var $this = $(this);
					var dataThumb = $(this).attr('data-thumb');

					return {
						src: dataThumb || $this.attr('href'),
						type: 'image',
					};
				}).get();
			},
		},
	});

	$( '.ci-vid-lightbox' ).magnificPopup({
		type: 'iframe',
		mainClass: 'mfp-fade'
	} );

	/* -----------------------------------------
	Instagram slideshow
	----------------------------------------- */
	var $instagramWrap   = $('.footer-instagram');
	var $instagramWidget = $instagramWrap.find('.instagram-pics');

	if ( $instagramWidget.length ) {
		var auto  = $instagramWrap.data('auto');
		var speed = $instagramWrap.data('speed');

		$instagramWidget.slick({
			slidesToShow: 8,
			slidesToScroll: 3,
			arrows: false,
			autoplay: auto == 1,
			speed: speed,
			responsive: [
				{
					breakpoint: 991,
					settings: {
						slidesToShow: 6
					}
				},
				{
					breakpoint: 767,
					settings: {
						slidesToShow: 4
					}
				}
			]
		});
	}

	/* -----------------------------------------
	Input add/minus
	----------------------------------------- */
	var $qtyHandle = $('.qty-handle');
	var hasAttribute = function ($el, attr) {
		return $el.get(0).hasAttribute(attr) && $el.attr(attr) !== '';
	};

	$qtyHandle.on('click', function (e) {
		var $this     = $(this);
		var $qtyInput = $this.siblings('input');
		var step      = parseInt($qtyInput.attr('step')) || 1;
		var min       = hasAttribute($qtyInput, 'min') ? parseInt($qtyInput.attr('min')) : 1;
		var max       = hasAttribute($qtyInput, 'max') ? parseInt($qtyInput.attr('max')) : Infinity;
		var value     = parseInt($qtyInput.val());

		if ($this.hasClass('qty-minus')) {
			if (value > min) {
				$qtyInput.val(value - 1);
			}
		} else {
			if (value < max) {
				$qtyInput.val(value + 1);
			}
		}

		e.preventDefault();
	});

	/* -----------------------------------------
	Product Sliders
	----------------------------------------- */
	var $rowSliders = $('.row-slider');

	function getBreakpointsFromClasses(classes) {
		return classes.split(' ').map(function (c) {
			var classData = c.split('-');
			var breakpoint;

			if (classData[1] === 'lg') {
				breakpoint = 1200;
			} else if (classData[1] === 'md' ) {
				breakpoint = 992;
			} else if (classData[1] === 'sm') {
				breakpoint = 768;
			}

			var slideNo = 12 / parseInt(classData[2]);

			return {
				breakpoint: breakpoint,
				settings: {
					slidesToShow: slideNo,
					slidesToScroll: slideNo
				}
			}
		});
	}

	$rowSliders.each(function () {
		var $this = $(this);
		var classes = $this
			.find('div[class^="col"]')
			.first()
			.attr('class');
		var slidesNo = 12 / parseInt(classes.split(' ')[0].split('-')[2]);

		$this.slick({
			infinite: false,
			slidesToShow: slidesNo,
			slidesToScroll: slidesNo,
			appendArrows: $this.parent().find('.row-slide-nav'),
			prevArrow: '<span><i class="fa fa-angle-left"></i></span>',
			nextArrow: '<span><i class="fa fa-angle-right"></i></span>',
			responsive: getBreakpointsFromClasses(classes)
		});
	});

	$( window ).on( 'load', function() {
		/* -----------------------------------------
		MatchHeight
		----------------------------------------- */
		$( '.row-equal' ).find( '[class^="col"]' ).matchHeight();

		/* -----------------------------------------
		Custom Scrollbar
		----------------------------------------- */
		$( '.custom-scrollbar' ).mCustomScrollbar({
			theme: 'minimal-dark'
		});

		/* -----------------------------------------
		Revealing Footer
		----------------------------------------- */
		var $footer = $('.footer');
		var $footerFix = $('.footer-fixed');
		var $footerWrap = $('.footer-wrap');

		if ($footer.hasClass('footer-revealing')) {
			$footerWrap.css({
				marginBottom: $footerFix.height()
			});
		}
	});
});
