<?php
	if ( ! defined( 'ABSPATH' ) ) {
		die( '-1' );
	}

	/**
	 * Shortcode attributes
	 * @var $atts
	 * @var $content
	 * @var $title
	 * @var $subtitle
	 * @var $text_align
	 * @var $title_color
	 * @var $subtitle_color
	 * @var $el_class
	 * @var $css
	 */

	$atts = vc_map_get_attributes( $this->getShortcode(), $atts );

	$custom_class = vc_shortcode_custom_css_class( $atts['css'] );
	if ( empty( $custom_class ) ) {
		$custom_class = uniqid( 'temp_vc_' );
	}

	$wrapper_classes = array(
		$this->getExtraClass( $atts['el_class'] ),
		$custom_class,
	);

	$wrapper_classes = array_map( 'trim', $wrapper_classes );
	$class_to_filter = implode( ' ', array_filter( $wrapper_classes ) );
	$css_classes     = apply_filters( VC_SHORTCODE_CUSTOM_CSS_FILTER_TAG, $class_to_filter, $this->settings['base'], $atts );

	$link_attrs = vc_build_link( $atts['link_url'] );
	$a_target   = '';
	$a_rel      = '';
	$a_title    = '';

	$title_size    = absint( $atts['title_size'] );
	$subtitle_size = absint( $atts['subtitle_size'] );


	if ( ! empty( $link_attrs['target'] ) ) {
		$a_target = sprintf( 'target="%s" ', esc_attr( $link_attrs['target'] ) );
	}
	if ( ! empty( $link_attrs['rel'] ) ) {
		$a_rel = sprintf( 'rel="%s" ', esc_attr( $link_attrs['rel'] ) );
	}
	if ( ! empty( $link_attrs['title'] ) ) {
		$a_rel = sprintf( 'title="%s" ', esc_attr( $link_attrs['title'] ) );
	}


	$container_styles = array();

	$text_align = neto_sanitize_align( $atts['text_align'] );
	if ( ! empty( $text_align ) ) {
		$container_styles[] = sprintf( 'text-align: %s; ',
			$text_align
		);
	}

	$title_styles = array();
	if ( ! empty( $atts['title_color'] ) ) {
		$title_styles[] = sprintf( 'color: %s; ',
			$atts['title_color']
		);
	}
	if ( ! empty( $atts['title_size'] ) ) {
		$title_styles[] = sprintf( 'font-size: %spx; ',
			$atts['title_size']
		);
	}


	$subtitle_styles = array();
	if ( ! empty( $atts['subtitle_color'] ) ) {
		$subtitle_styles[] = sprintf( 'color: %s; ',
			$atts['subtitle_color']
		);
	}
	if ( ! empty( $atts['subtitle_size'] ) ) {
		$subtitle_styles[] = sprintf( 'font-size: %spx; ',
			$atts['subtitle_size']
		);
	}



	if ( $link_attrs['url'] ) {
		echo sprintf( '<a href="%s" %s%s%s>',
			esc_url( $link_attrs['url'] ),
			$a_target,
			$a_rel,
			$a_title
		);
	}

	?>
	<section class="vc_ci-banner-container <?php echo esc_attr( $css_classes ); ?>" style="<?php echo esc_attr( implode( ' ', $container_styles ) ); ?>">
		<?php if ( ! empty( $atts['title'] ) || ! empty( $atts['subtitle'] ) ) : ?>
			<header class="vc_ci-banner-content-header">
				<?php if ( ! empty( $atts['title'] ) ) : ?>
					<h2 style="<?php echo esc_attr( implode( ' ', $title_styles ) ); ?>">
						<?php echo esc_html( $atts['title'] ); ?>
					</h2>
				<?php endif; ?>
				<?php if ( ! empty( $atts['subtitle'] ) ) : ?>
					<h4 style="<?php echo esc_attr( implode( ' ', $subtitle_styles ) ); ?>">
						<?php echo esc_html( $atts['subtitle'] ); ?>
					</h4>
				<?php endif; ?>
			</header>
		<?php endif; ?>

		<?php if ( ! empty( $content ) ) : ?>
			<div class="vc_ci-banner-content">
				<?php echo wpb_js_remove_wpautop( $content, true ); ?>
			</div>
		<?php endif; ?>
	</section>
	<?php

	if ( $link_attrs['url'] ) {
		echo '</a>';
	}
