<?php
/**
 * The Template for displaying product archives, including the main shop page which is a post type archive
 *
 * This template can be overridden by copying it to yourtheme/woocommerce/archive-product.php.
 *
 * HOWEVER, on occasion WooCommerce will need to update template files and you
 * (the theme developer) will need to copy the new files to your theme to
 * maintain compatibility. We try to do this as little as possible, but it does
 * happen. When this occurs the version of the template file will be bumped and
 * the readme will list any important changes.
 *
 * @see 	    https://docs.woocommerce.com/document/template-structure/
 * @package 	WooCommerce/Templates
 * @version     3.4.0
 */

defined( 'ABSPATH' ) || exit;

$classes = neto_get_shop_content_sidebar_classes( get_theme_mod( 'woocommerce_shop_layout', 'left' ) );

get_header( 'shop' ); ?>

	<?php
		$show_hero = false;
		if ( is_shop() ) {
			$show_hero = (bool) get_theme_mod( 'woocommerce_shop_hero_show', 1 );
		} else {
			$show_hero = (bool) get_theme_mod( 'woocommerce_tax_hero_show', 1 );
			$term      = get_term( get_queried_object_id() );
			$cat_hero  = get_term_meta( $term->term_id, 'hero_show', true );
			if ( 'yes' === $cat_hero ) {
				$show_hero = true;
			} elseif ( 'no' === $cat_hero ) {
				$show_hero = false;
			}
		}
	?>

	<?php if ( $show_hero ) : ?>
		<section class="page-hero <?php echo esc_attr( neto_get_section_align_class() ); ?>">
			<div class="container">
				<div class="row">
					<div class="col-xs-12">
						<?php if ( apply_filters( 'woocommerce_show_page_title', true ) ) : ?>

							<h1 class="page-hero-title"><?php woocommerce_page_title(); ?></h1>

						<?php endif; ?>

						<?php
							/**
							 * woocommerce_archive_description hook.
							 *
							 * @hooked woocommerce_taxonomy_archive_description - 10
							 * @hooked woocommerce_product_archive_description - 10
							 */
							do_action( 'woocommerce_archive_description' );
						?>
					</div>
				</div>
			</div>
		</section>
	<?php endif; ?>

	<?php
		/**
		 * woocommerce_before_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper - 10 (outputs opening divs for the content)
		 * @hooked woocommerce_breadcrumb - 20
		 * @hooked wc_print_notices - 20 // Added by theme.
		 * @hooked WC_Structured_Data::generate_website_data() - 30
		 */
		do_action( 'woocommerce_before_main_content' );
	?>

		<div class="<?php echo esc_attr( $classes['content'] ); ?>">

			<?php if ( woocommerce_product_loop() ) : ?>

				<?php if ( false === $classes['has_sidebar'] && is_active_sidebar( 'eshop' ) ) : ?>
					<div class="sidebar sidebar-drawer">
						<div class="sidebar-drawer-header">
							<a href="#" class="sidebar-dismiss"><i class="fa fa-close"></i> <span class="screen-reader-text"><?php esc_html_e( 'Close drawer', 'neto' ); ?></span></a>
						</div>

						<div class="sidebar-drawer-content custom-scrollbar">
							<?php dynamic_sidebar( 'eshop' ); ?>
						</div>
					</div>
				<?php endif; ?>

				<div class="shop-actions">
					<?php
						/**
						 * woocommerce_before_shop_loop hook.
						 *
						 * @hooked woocommerce_result_count - 20 // Removed by theme. Called withing neto_woocommerce_shop_actions()
						 * @hooked neto_woocommerce_shop_actions - 20 // Added by theme.
						 * @hooked woocommerce_catalog_ordering - 30
						 */
						do_action( 'woocommerce_before_shop_loop' );
					?>
				</div>

				<?php woocommerce_product_loop_start(); ?>

					<?php woocommerce_product_subcategories(); ?>

					<?php while ( have_posts() ) : the_post(); ?>

						<?php
							/**
							 * woocommerce_shop_loop hook.
							 *
							 * @hooked WC_Structured_Data::generate_product_data() - 10
							 */
							do_action( 'woocommerce_shop_loop' );
						?>

						<?php wc_get_template_part( 'content', 'product' ); ?>

					<?php endwhile; // end of the loop. ?>

				<?php woocommerce_product_loop_end(); ?>

				<?php
					/**
					 * woocommerce_after_shop_loop hook.
					 *
					 * @hooked woocommerce_pagination - 10
					 */
					do_action( 'woocommerce_after_shop_loop' );
				?>

			<?php elseif ( ! woocommerce_product_subcategories( array( 'before' => woocommerce_product_loop_start( false ), 'after' => woocommerce_product_loop_end( false ) ) ) ) : ?>

				<?php wc_get_template( 'loop/no-products-found.php' ); ?>

			<?php endif; ?>

		</div>

		<?php if ( $classes['has_sidebar'] ) : ?>
			<div class="<?php echo esc_attr( $classes['sidebar'] ); ?>">
				<?php
					/**
					 * woocommerce_sidebar hook.
					 *
					 * @hooked woocommerce_get_sidebar - 10
					 */
					do_action( 'woocommerce_sidebar' );
				?>
			</div>
		<?php endif; ?>

	<?php
		/**
		 * woocommerce_after_main_content hook.
		 *
		 * @hooked woocommerce_output_content_wrapper_end - 10 (outputs closing divs for the content)
		 */
		do_action( 'woocommerce_after_main_content' );
	?>

<?php get_footer( 'shop' ); ?>
